@@ -417,6 +417,7 @@ protected:
     long      dbConnect();
     long      setFixedCelldbItem(WSCdbRecord* rs);
     long      dbDataSet();
+    WSCstring getDbErrorMsg();
     
 
 protected:
@@ -489,6 +490,7 @@ protected:
     WSCstring   _dbwork;
     WSCbool     _dbCellAutoResize;
     WSCbool     _dbCellTitle;
+    WSCstring   _dbError;
     
 protected:
     WSMFpropertyDef(WSNrows, long, _rows);
@@ -496,8 +498,8 @@ protected:
     WSMFpropertyDef(WSNfixedRows, long, _fixedRows);
     WSMFpropertyDef(WSNfixedCols, long, _fixedCols);
     WSMFpropertyDef(WSNgridLines, short, _gridLines);
-    WSMFpropertyDef(WSNcelldefWidth, long, _colWidth);
-    WSMFpropertyDef(WSNcelldefHeight, long, _colHeight);
+    WSMFpropertyDef(WSNcellDefWidth, long, _colWidth);
+    WSMFpropertyDef(WSNcellDefHeight, long, _colHeight);
     WSMFpropertyDef(WSNfixedColHeight, long, _fixedColHeight);
     WSMFpropertyDef(WSNcellDefFont, short, _font);
     WSMFpropertyDef(WSNfixedCellFont, short, _fixedFont);
