@@ -24,8 +24,8 @@
 // Toshikaz Hirabayashi.
 
 
-#ifndef WSDXSCRDEV_H
-#define WSDXSCRDEV_H
+#ifndef WSDWINSCRDEV_H
+#define WSDWINSCRDEV_H
 
 #include <win/WSDwinformDev.h>
 
