@@ -202,8 +202,8 @@
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","k3:WSSTR Belong to this project","プロジェクトへ登録");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Member","メンバ");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR ENCODING","コード体系");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR COMPAT","互換性");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Platform compatible","プラットホーム互換");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR COMPAT","TARGET");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Platform compatible","プラットフォーム互換");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Look & Feel","Look & Feel");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Gradation","Gradation");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Gui Policy","ＧＵＩポリシー");
@@ -230,12 +230,12 @@
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","F3:WSSTR Return value type:","返値型");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","H3:WSSTR Name/Type","名称/型");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","R3:WSSTR The method name is already used.","指定されたメソッド名称は既に使用されています。");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","S3:WSSTR Invalid method name.", "不正なメソッド名称です。");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","V3:WSSTR Please select the method.", "メソッドを選択してください。");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","d3:WSSTR RemoteClassName:", "仮想リモートクラス名称:");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","d3:WSSTR BaseClassName:", "派生元仮想リモートクラス名称:");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Language", "言語");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","K3:WSSTR Edit...", "設定...");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","S3:WSSTR Invalid method name.","不正なメソッド名称です。");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","V3:WSSTR Please select the method.","メソッドを選択してください。");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","d3:WSSTR RemoteClassName:","仮想リモートクラス名称:");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","d3:WSSTR BaseClassName:","派生元仮想リモートクラス名称:");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Language","言語");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","K3:WSSTR Edit...","設定...");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","W3:WSSTR Name of the struct:","構造体名称");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","W3:WSSTR Name of the value:","値名称");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","W3:WSSTR Value:","値");
@@ -246,6 +246,6 @@
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","P3:WSSTR Python(DBG)","Python(DBG)");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","P3:WSSTR Perl","Perl");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","P3:WSSTR Perl(DBG)","Perl(DBG)");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","f3:WSSTR Static option","DLL無しビルド");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","f3:WSSTR Static option","リンク方式");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Statically linked","スタティックリンク(DLL 無し)");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Dynamically linked","ダイナミックリンク(DLL あり)");
