@@ -202,8 +202,8 @@
   WSGIappLocaleSet()->setLocaleString("EUCJP","k3:WSSTR Belong to this project","ץȤϿ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Member","");
   WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR ENCODING","η");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR COMPAT","ߴ");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Platform compatible","ץåȥۡߴ");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR COMPAT","TARGET");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Platform compatible","ץåȥեߴ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Look & Feel","Look & Feel");
   WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Gradation","Gradation");
   WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Gui Policy","ǣգɥݥꥷ");
@@ -230,12 +230,12 @@
   WSGIappLocaleSet()->setLocaleString("EUCJP","F3:WSSTR Return value type:","ͷ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","H3:WSSTR Name/Type","̾/");
   WSGIappLocaleSet()->setLocaleString("EUCJP","R3:WSSTR The method name is already used.","ꤵ줿᥽å̾Τϴ˻ѤƤޤ");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR Invalid method name.", "ʥ᥽å̾ΤǤ");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR Please select the method.", "᥽åɤ򤷤Ƥ");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR RemoteClassName:", "ۥ⡼ȥ饹̾:");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR BaseClassName:", "ۥ⡼ȥ饹̾:");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Language", "");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","K3:WSSTR Edit...", "...");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","S3:WSSTR Invalid method name.","ʥ᥽å̾ΤǤ");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR Please select the method.","᥽åɤ򤷤Ƥ");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR RemoteClassName:","ۥ⡼ȥ饹̾:");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","d3:WSSTR BaseClassName:","ۥ⡼ȥ饹̾:");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Language","");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","K3:WSSTR Edit...","...");
   WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Name of the struct:","¤̾");
   WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Name of the value:","̾");
   WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Value:","");
