@@ -1,23 +1,23 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","","");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","A3:WSSTR Can not create class: %s.\nPlease check the import library is right.","Ŭ  %s  մϴ.\n߰Ʈ  ´° Ȯּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","B3:WSSTR The name %s is already used by another instance.","Ʈ  %s   ܰͰ Ī ߺϰֽϴ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","C3:WSSTR Normal:0:,Invisible:4:,Deleted:1:,Default changed:2:,Hidden:3:",":0:,Ұ:4:,:1:,ʱġ:2:,Ұȭ:3:");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","A3:WSSTR Can not create class: %s.\nPlease check the import library is right.","Ŭ  %s  մϴ.\n߰Ʈ  ´ Ȯּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","B3:WSSTR The name %s is already used by another instance.","Ʈ  %s   ܰͰ ̸ ߺϰֽϴ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","C3:WSSTR Normal:0:,Invisible:4:,Deleted:1:,Default changed:2:,Hidden:3:",":0:,Ұ:4:,:1:,ʱⰪ:2:,Ұȭ:3:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","D3:WSSTR Target class:","ϴŬ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","E3:WSSTR Property name:","Ƽ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR Property type:","Ƽ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","G3:WSSTR Variable name:",":");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","H3:WSSTR Default value:","Ʈġ:");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","H3:WSSTR Default value:","Ʈ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","I3:WSSTR Attribute:","ǼӼ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","J3:WSSTR Builder title:","ŸƲ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","K3:WSSTR Select menu:"," ϶:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","L3:WSSTR Warning","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","M3:WSSTR Invalid property name.\nPlease specify another name like WSNxxxx...","WSN  ۵Ǵ ùٸ Ƽ\nּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR Invalid variable name...","ùٸ  ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","O3:WSSTR This name is already used by another procedure..."," Ī ν\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR This name is already used by another external instace."," Ī ٸ ܺμƮĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","Q3:WSSTR This name is already used by another external instace array."," Ī ٸ ܺμƮĸĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR This property name is already used by another property.","Ƽ ߺϰ־.\n ٸ Ī ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR The variable is already used."," ߺϰ־.\nٸ Ī ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","O3:WSSTR This name is already used by another procedure..."," ̸ ν\nߺϱ⿡ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR This name is already used by another external instace."," ̸ ٸ ܺμƮ̸\nߺϱ⿡ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","Q3:WSSTR This name is already used by another external instace array."," ̸ ٸ ܺμƮ̸\nߺϱ⿡ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR This property name is already used by another property.","Ƽ ߺϰ־.\n ٸ ̸ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR The variable is already used."," ߺϰ־.\nٸ ̸ ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","T3:WSSTR Create","ۼ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","U3:WSSTR Please specify the target class window.","Ŭ ֻ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","V3:WSSTR Please select the property.","Ƽ ּ.");
@@ -27,50 +27,50 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","Z3:WSSTR Create new property","Ƽ ۼ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","a3:WSSTR Edit property","Ƽ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","b3:WSSTR Delete property","Ƽ ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Type,Property name,Member name,Attribute,Default value",",Ƽ,,Ӽ,Ʈġ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Type,Property name,Member name,Attribute,Default value",",Ƽ,,Ӽ,Ʈ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","d3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:"," ۼ:NEW:,:EDIT:,:DEL:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","e3:WSSTR  Use the handler defined by user","  ڵ鷯 ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","f3:WSSTR (Normal)","()");
   WSGIappLocaleSet()->setLocaleString("EUCKR","g3:WSSTR (Delete)","()");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","h3:WSSTR (DefaultChange)","(ʱġ )");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","h3:WSSTR (DefaultChange)","(ʱⰪ )");
   WSGIappLocaleSet()->setLocaleString("EUCKR","i3:WSSTR (Etherealize)","(Ұȭ )");
   WSGIappLocaleSet()->setLocaleString("EUCKR","j3:WSSTR (Invisible)","(Ұ Ӽ)");
   WSGIappLocaleSet()->setLocaleString("EUCKR","k3:WSSTR Normal Def.:0:,Delete Def.:1:",":0:,Ʈ :1:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Target class:","ϴŬ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","m3:WSSTR Trigger name:","ƮŸ:");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","n3:WSSTR Define name:"," ڷ:");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","n3:WSSTR Define name:"," ڿ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","o3:WSSTR Define value:"," :");
   WSGIappLocaleSet()->setLocaleString("EUCKR","p3:WSSTR Define type:","ǼӼ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","q3:WSSTR Invalid trigger name.","̽ ȵ  ƮŸ\nּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","r3:WSSTR Invalid define string...","ùٸ  ڷ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","r3:WSSTR Invalid define string...","ùٸ  ڿ ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","s3:WSSTR Please specify the define value > 31.","32 ̻  ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","t3:WSSTR This trigger name is already used by another one.","ƮŸ ߺϰ־.\nٸ Ī ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","u3:WSSTR The define string is already used.","ιڷ ߺϰ־.\nٸ   ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","t3:WSSTR This trigger name is already used by another one.","ƮŸ ߺϰ־.\nٸ ̸ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","u3:WSSTR The define string is already used.","ιڿ ߺϰ־.\nٸ   ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","v3:WSSTR The value is already used.","  ߺϰ־.\nٸ  ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","w3:WSSTR Please select the trigger.","ƮŸ ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","x3:WSSTR Is it OK to delete the trigger?","ƮŸ ص ϱ?");
   WSGIappLocaleSet()->setLocaleString("EUCKR","y3:WSSTR Create new trigger","Ʈ ۼ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","z3:WSSTR Edit trigger","Ʈ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","A3:WSSTR Delete trigger","Ʈ ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","B3:WSSTR Trigger Name,Trigger def,Trigger value,Attribute","ƮŸ, ڷ, ,ǼӼ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","B3:WSSTR Trigger Name,Trigger def,Trigger value,Attribute","ƮŸ, ڿ, ,ǼӼ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","C3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:"," ۼ:NEW:,:EDIT:,:DEL:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","D3:WSSTR All:",":");
   WSGIappLocaleSet()->setLocaleString("EUCKR","E3:WSSTR R:",":");
   WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR G:",":");
   WSGIappLocaleSet()->setLocaleString("EUCKR","G3:WSSTR B:","û:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","H3:WSSTR Color:"," :");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","I3:WSSTR Name:"," Ī:");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","I3:WSSTR Name:"," ̸:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","J3:WSSTR Add user color","ǻ ߰");
   WSGIappLocaleSet()->setLocaleString("EUCKR","K3:WSSTR Edit user color","ǻ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","L3:WSSTR Delete user color","ǻ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","M3:WSSTR Default colors,Standard colors,User defined colors","Ʈ,Ĵ,ǻ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR Please select the user color."," ǻ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR Please select the user color."," ǻ  ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","O3:WSSTR Delete the selected color: ","õ : ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR  ?","  ϰڽϱ?");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","Q3:WSSTR Please select the user color to delete."," ǻ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR  ?","  Ͻðڽϱ?");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","Q3:WSSTR Please select the user color to delete."," ǻ  ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR %s:DISP:,Save:SAVE:,Search:SEARCH:,SP,Compile:COMP:,%s:PRJ:,SP,Copy:COPY:,Paste:PASTE:,SP,Delete:DEL:","%s:DISP:,:SAVE:,˻:SEARCH:,SP,:COMP:,%s:PRJ:,SP,:COPY:,̱:PASTE:,SP,:DEL:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR Files,Instances,Properties,Procedures,Attributes",",νϽ,Ƽ,ν,⺻");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","T3:WSSTR Name,Class","Ī,Ŭ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","T3:WSSTR Name,Class","̸,Ŭ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","U3:WSSTR None:NONE:",":NONE:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","V3:WSSTR Display","ǥ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Add to project","Ʈ ");
@@ -87,10 +87,10 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","h3:WSSTR Invalid procedure name...","ùٸ ν ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","i3:WSSTR Invalid function name...","ùٸ  ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","j3:WSSTR Invalid procedure name...","ùٸ ν ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","k3:WSSTR Invalid procedure name.\nAlready used by another proceudre name."," Ī ν\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Invalid procedure name.\nAlready used by another instance name."," Ī ٸ ܺμƮĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","m3:WSSTR Invalid procedure name.\nAlready used by another instance array name."," Ī ٸ ܺμƮĸĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","n3:WSSTR Invalid function name.","ڸ   ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","k3:WSSTR Invalid procedure name.\nAlready used by another proceudre name."," ̸ ν\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Invalid procedure name.\nAlready used by another instance name."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","m3:WSSTR Invalid procedure name.\nAlready used by another instance array name."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","n3:WSSTR Invalid function name.","ڸ    ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","o3:WSSTR Cleate %s.cpp...","%s.cpp\n ۼϰڽϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","p3:WSSTR Cleate %s/%s.cpp...","%s/%s.cpp\n ۼϰڽϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","o3:WSSTR Create %s.rb...","%s.rb\n ۼϰڽϴ.");
@@ -101,18 +101,18 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","p3:WSSTR Create %s/%s.pl...","%s/%s.pl\n ۼϰڽϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","q3:WSSTR Overwrite existing file: %s?","%s\n ֽϴ.մϱ?");
   WSGIappLocaleSet()->setLocaleString("EUCKR","r3:WSSTR OK","ۼ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","s3:WSSTR Please specify a target instance.","Ʈ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","t3:WSSTR Please select a procedure.","ν ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","s3:WSSTR Please specify a target instance.","Ʈ  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","t3:WSSTR Please select a procedure.","ν  ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","u3:WSSTR The procedure does not exist."," ν ϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","v3:WSSTR Delete this procedure?","ν ص ϱ?");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","w3:WSSTR Procedure name,Trigger,Function name","νĪ,Ʈ,");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","w3:WSSTR Procedure name,Trigger,Function name","ν̸,Ʈ,");
   WSGIappLocaleSet()->setLocaleString("EUCKR","x3:WSSTR File..."," ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","y3:WSSTR Template","ø ۼ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","z3:WSSTR Internal","ҽ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","A3:WSSTR New:NEW:,Properties:SET:,Edit procedure:EDIT:,Delete procedure:DEL:"," ۼ:NEW:,ν:SET:, :EDIT:,:DEL:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","B3:WSSTR done.\n","ϴ.\n");
   WSGIappLocaleSet()->setLocaleString("EUCKR","C3:WSSTR Break","");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","D3:WSSTR Defaults,Environments,Imports,Compiling,Linking,Fonts,Etc..","Ʈġ,ȯ漳,߰,,ũ,Ʈ,⺻");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","D3:WSSTR Defaults,Environments,Imports,Compiling,Linking,Fonts,Etc..","Ʈ,ȯ漳,߰,,ũ,۲,⺻");
   WSGIappLocaleSet()->setLocaleString("EUCKR","E3:WSSTR Default colors","Ʈ  ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR Default size","Ʈ ũ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","G3:WSSTR Grid size","׸ ");
@@ -136,53 +136,53 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode"," , , ƽ , ƽ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","Y3:WSSTR Include path","Ŭн");
   WSGIappLocaleSet()->setLocaleString("EUCKR","Z3:WSSTR Compiler flags","÷");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","a3:WSSTR Include path","׿Ŭн");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","b3:WSSTR Compiler flags","׿÷");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","a3:WSSTR Include path","׿ Ŭн");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","b3:WSSTR Compiler flags","׿ ÷");
   WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Libraries","̺귯");
   WSGIappLocaleSet()->setLocaleString("EUCKR","d3:WSSTR Linker flags","븵Ŀ÷");
   WSGIappLocaleSet()->setLocaleString("EUCKR","e3:WSSTR Linker","Ŀ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","f3:WSSTR Debugger","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","f3:WSSTR Make","ũ Ŀǵ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","g3:WSSTR Runitme mode,Debug mode",",׸");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","g3:WSSTR Runtime mode,Debug mode",",׸");
   WSGIappLocaleSet()->setLocaleString("EUCKR","h3:WSSTR Libraries","̺귯");
   WSGIappLocaleSet()->setLocaleString("EUCKR","i3:WSSTR Output file","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","j3:WSSTR Libraries","׿̺귯");
   WSGIappLocaleSet()->setLocaleString("EUCKR","k3:WSSTR Output file","׿");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Please select a target to delete."," ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","m3:WSSTR No-name","Ī-Ҹ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","n3:WSSTR Name:WSN%s  Type:%s","Ī:WSN%s  :%s");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","o3:WSSTR Invalid instance name.\nAlready used by another function name..."," Ī ν\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","p3:WSSTR Invalid instance name.\nAlready used by another instance name..."," Ī ٸ ƮĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","q3:WSSTR Invalid instance name.\nAlready used by another instance array name..."," Ī ٸ ĸĪ ߺϱ⿡\nּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","r3:WSSTR Invalid instance name.\nAlready used by project name or something..."," Ī Ʈ Ī\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","s3:WSSTR Can not use array name for application window.","ø̼忡ؼ ĸĪ ϴ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Please select a target to delete.","  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","m3:WSSTR No-name","̸-Ҹ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","n3:WSSTR Name:WSN%s  Type:%s","̸:WSN%s  :%s");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","o3:WSSTR Invalid instance name.\nAlready used by another function name..."," ̸ ν\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","p3:WSSTR Invalid instance name.\nAlready used by another instance name..."," ̸ ٸ Ʈ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","q3:WSSTR Invalid instance name.\nAlready used by another instance array name..."," ̸ ٸ ̸ ߺϱ⿡\n ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","r3:WSSTR Invalid instance name.\nAlready used by project name or something..."," ̸ Ʈ ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","s3:WSSTR Can not use array name for application window.","ø̼忡ؼ ̸ ϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","t3:WSSTR Can not use array name for class window.","Ŭ忡  ϴ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","u3:WSSTR Invalid instance name.\nAlready used by another procedure name..."," Ī ν\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","v3:WSSTR Invalid instance name.\nAlready used by another external instance name..."," Ī ٸ ܺμƮĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","w3:WSSTR Invalid instance array name.\nAlready used by another window, or invalid type."," Ī ٸ  ĸĪ ߺϴ°\nȤ  ġϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","x3:WSSTR Invalid instance name.\nAlready used by project name or something..."," Ī Ʈ Ī\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","y3:WSSTR Invalid instance name.","ùٸ ƮĪ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","u3:WSSTR Invalid instance name.\nAlready used by another procedure name..."," ̸ ν\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","v3:WSSTR Invalid instance name.\nAlready used by another external instance name..."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","w3:WSSTR Invalid instance array name.\nAlready used by another window, or invalid type."," ̸ ٸ  ̸ ߺϴ°\nȤ  ġϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","x3:WSSTR Invalid instance name.\nAlready used by project name or something..."," ̸ Ʈ ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","y3:WSSTR Invalid instance name.","ùٸ Ʈ̸  ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","z3:WSSTR This trigger already exists."," ƮŴ մϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","A3:WSSTR This trigger already exists."," ƮŴ մϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","B3:WSSTR Can not delete the fixed trigger."," ƮŴ մϴ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","C3:WSSTR Please select a trigger to delete."," ƮŸ ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","C3:WSSTR Please select a trigger to delete."," ƮŸ  ּ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","D3:WSSTR BaseClass","Ļ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","E3:WSSTR Base","̽");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR If you change window definition type,\nyou have to change the type of the event procedure.\nDo you contine?","Ÿ ϸ \n̺Ʈν ǰ ٸ⿡\n ϰԵ 찡ֽ ϰڽϱ?");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR If you change window definition type,\nyou have to change the type of the event procedure.\nDo you contine?","Ÿ ϸ \n̺Ʈν ǰ ٸ⿡\n ϰԵ 찡ֽ Ͻðڽϱ?");
   WSGIappLocaleSet()->setLocaleString("EUCKR","G3:WSSTR If it makes the class definition window type into another type,\nit needs to change the type of the event procedure.\nDo you contine?","Ŭ  ٸ ŸԿ ϸ\n̺Ʈν ǰ ٸ⿡\n ϰԵ 찡 ϰڽϱ?");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","H3:WSSTR inherit base instance: %s Not Found.\nPlease specify the correct instance name.","Ļ   νϽ: %s \n ϴ. νϽ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","I3:WSSTR Invalid name.\nAlready used by another event procedure."," Ī ν \nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","J3:WSSTR Invalid name.\nAlready used by another instance name."," Ī ٸ ƮĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","K3:WSSTR Invalid name.\nAlready used by another instance array name."," Ī ٸ ĸĪ ߺ̿\nּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","L3:WSSTR Invalid name.\nAlready used by the project name or the other one."," Ī Ʈ Ī\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","M3:WSSTR Can not specify the array name for window.","忡 ؼ ĸĪ ϴ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","H3:WSSTR inherit base instance: %s Not Found.\nPlease specify the correct instance name.","Ļ   νϽ: %s \n ϴ. νϽ  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","I3:WSSTR Invalid name.\nAlready used by another event procedure."," ̸ ν \nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","J3:WSSTR Invalid name.\nAlready used by another instance name."," ̸ ٸ Ʈ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","K3:WSSTR Invalid name.\nAlready used by another instance array name."," ̸ ٸ ̸ ߺ̿\n ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","L3:WSSTR Invalid name.\nAlready used by the project name or the other one."," ̸ Ʈ ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","M3:WSSTR Can not specify the array name for window.","忡 ؼ ̸ ϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR Can not specify the array name for class definition window.","Ŭ忡  ϴ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","O3:WSSTR Invalid name.\nAlready used by another event procedure."," Ī ν \nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR Invalid name.\nAlready used by another externalinstance."," Ī ٸ ܺμƮĪ\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","Q3:WSSTR Invalid array name.\nThe Array type differs from another one,or exists also another window."," Ī ٸ  ĸĪ ߺϴ°\nȤ  ġϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR Invalid name.\nAlready used by the project name or the other one."," Ī Ʈ ٸ Ī\nߺϱ⿡ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR Invalid instance name.","ùٸ ƮĪ ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","T3:WSSTR ClassName","ŬĪ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","O3:WSSTR Invalid name.\nAlready used by another event procedure."," ̸ ν \nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR Invalid name.\nAlready used by another externalinstance."," ̸ ٸ ܺμƮ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","Q3:WSSTR Invalid array name.\nThe Array type differs from another one,or exists also another window."," ̸ ٸ  ̸ ߺϴ°\nȤ  ġϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR Invalid name.\nAlready used by the project name or the other one."," ̸ Ʈ ٸ ̸\nߺϱ⿡  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR Invalid instance name.","ùٸ Ʈ̸  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","T3:WSSTR ClassName","Ŭ̸");
   WSGIappLocaleSet()->setLocaleString("EUCKR","U3:WSSTR Normal window","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","V3:WSSTR Class definition","Ŭ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Use object store"," ̿");
@@ -194,15 +194,15 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Icon","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","d3:WSSTR Comment","ڸƮ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","e3:WSSTR Base","Ļ ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","f3:WSSTR Name","Ī");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","g3:WSSTR File name","ϸĪ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","f3:WSSTR Name","̸");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","g3:WSSTR File name","̸");
   WSGIappLocaleSet()->setLocaleString("EUCKR","h3:WSSTR Access","Ӽ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","i3:WSSTR Global variable","۷ι");
   WSGIappLocaleSet()->setLocaleString("EUCKR","j3:WSSTR Project","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","k3:WSSTR Belong to this project","Ʈ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Member","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR ENCODING","ڵü");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR COMPAT","ȣȯ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR COMPAT","TARGET");
   WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Platform compatible","÷ȣȯ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Look & Feel","Look & Feel");
   WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Gradation","Gradation");
@@ -210,36 +210,36 @@
   WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR PropertyEditor","Ƽ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR PropertyName:","Ƽ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR PropertyType:","Ƽ:");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR PropertyValue:","Ƽġ:");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR PropertyValue:","Ƽ:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","N3:WSSTR breaked.","ó ߴ߽ϴ.");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR OBJS","߰Ʈ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR If you change class window name,\nyou have to reject your old source code\nand change the name of the event procedure.\nDo you contine?","Ŭ ϸ  ۼ ҽڵ峪\n̺Ʈν Ǹ ؾմϴ.\nϰڽϱ?");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR If you change class window name,\nyou have to reject your old source code\nand change the name of the event procedure.\nDo you contine?","Ŭ ϸ  ۼ ҽڵ峪\n̺Ʈν Ǹ ؾմϴ.\nϽðڽϱ?");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR ColorBox"," ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR MessageBox","޽ڽ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","j3:WSSTR RemoteClass","Ʈ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","k3:WSSTR Generates the virtual remote class"," Ʈ Ŭ ");
   WSGIappLocaleSet()->setLocaleString("EUCKR","b3:WSSTR RemoteMethods","Ʈ ޼");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Return type,Method name","ȯġ Ÿ,޼ Ī");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Return type,Method name","ȯ Ÿ,޼ ̸");
   WSGIappLocaleSet()->setLocaleString("EUCKR","G3:WSSTR Parameters","Ķ ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Type,Name",",Ī");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Type,Name",",̸");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Add","߰");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Del","");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Up"," ̵");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Down","Ʒ ̵");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","E3:WSSTR Method name:","޼ Ī");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR Return value type:","ȯġ ");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","H3:WSSTR Name/Type","Ī/");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR The method name is already used."," ޼ Ī ̹ ̿ǰ ֽϴ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR Invalid method name.", " ޼ ĪԴϴ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","V3:WSSTR Please select the method.", "޼带 ּ.");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","d3:WSSTR RemoteClassName:", " Ʈ Ŭ Ī:");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","d3:WSSTR BaseClassName:", "Ļ  Ʈ Ŭ Ī:");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","E3:WSSTR Method name:","޼ ̸");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","F3:WSSTR Return value type:","ȯ ");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","H3:WSSTR Name/Type","̸/");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","R3:WSSTR The method name is already used."," ޼ ̸ ̹ ̿Ǿ ֽϴ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","S3:WSSTR Invalid method name.", " ޼ ̸Դϴ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","V3:WSSTR Please select the method.", "޼带  ּ.");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","d3:WSSTR RemoteClassName:", " Ʈ Ŭ ̸:");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","d3:WSSTR BaseClassName:", "Ļ  Ʈ Ŭ ̸:");
   WSGIappLocaleSet()->setLocaleString("EUCKR","l3:WSSTR Language", "");
   WSGIappLocaleSet()->setLocaleString("EUCKR","K3:WSSTR Edit...", "...");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Name of the struct:","ü Ī");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Name of the value:"," Ī");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Name of the struct:","ü ̸");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Name of the value:"," ̸");
   WSGIappLocaleSet()->setLocaleString("EUCKR","W3:WSSTR Value:","");
-  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Name,Value","Ī,");
+  WSGIappLocaleSet()->setLocaleString("EUCKR","c3:WSSTR Name,Value","̸,");
   WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR Ruby","Ruby");
   WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR Ruby(DBG)","Ruby(DBG)");
   WSGIappLocaleSet()->setLocaleString("EUCKR","P3:WSSTR Python","Python");
