@@ -776,4 +776,10 @@ void WSCnwbase::_adjust_for_anchors(WSCushort w,WSCushort h){
     return;
   }
 }
+long WSCnwbase::getBlinkRate(){
+  return (long)_blink_rate;
+}
+WSCbool WSCnwbase::getBlinkRefresh(){
+  return (long)_bl_refreshing;
+}
 
