@@ -1076,10 +1076,10 @@ long WSCstring::replaceString(const char* srcchar,const char* destchar,long num,
     encode = WSGIappLocaleSet()->getSystemLocaleEncoding();
   } 
   if (encoding == WS_EN_SJIS && srcchar[0] == '\\'){
-    WSCstring eucstr;
-    eucstr.setString(getString(WS_EN_EUCJP),WS_EN_EUCJP);
-    long ret = eucstr.replaceString(srcchar,destchar,num,encode);
-    setString(eucstr.getString(WS_EN_SJIS),WS_EN_SJIS);
+    WSCstring ustr;
+    ustr.setString(getString(WS_EN_UTF8),WS_EN_UTF8);
+    long ret = ustr.replaceString(srcchar,destchar,num,encode);
+    setString(ustr.getString(WS_EN_SJIS),WS_EN_SJIS);
     return ret;
   }
   if (encoding != encode && encoding == WS_EN_NONE){
