@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -32,6 +32,7 @@
 #include <WSCbaseList.h>
 #include <WSCcolorSet.h>
 #include <WSDappDev.h>
+#include <WSDtimer.h>
 
 WSMFguiClassInitialize(WSCwindow,WSCbase);
 WSMFversion(WSCwindow,WSCbase);
@@ -91,6 +92,7 @@ WSCwindow::WSCwindow(WSCbase* base,char* objname):
   _a1_color = -1;
   _a2_color = -1;
   _a3_color = -1;
+  _vis_ch_sequence = False;
 
   WSMFpropertyCreateStart
     WSMFparentCheckVerSrc(WSCwindow);
@@ -271,18 +273,18 @@ void WSCwindow::getWorkWSNy(short* data){
 void WSCwindow::setWorkWSNwidth(WSCushort data){
   if (_initialized != False && _dev != NULL){
     _dev->setValue(WSDEV_WIDTH,(void*)&data);
-    _geometry_changed = True;
-    _update_resize = True;
   }
+  _geometry_changed = True;
+  _update_resize = True;
   adjustForm();
 }
 void WSCwindow::getWorkWSNwidth(WSCushort* ){}
 void WSCwindow::setWorkWSNheight(WSCushort data){
   if (_initialized != False && _dev != NULL){
     _dev->setValue(WSDEV_HEIGHT,(void*)&data);
-    _geometry_changed = True;
-    _update_resize = True;
   }
+  _geometry_changed = True;
+  _update_resize = True;
   adjustForm();
 }
 
@@ -522,7 +524,7 @@ long WSCwindow::_device_initialize(){
   dev->setValue(WSDEV_BACKCOLOR,(void*)&_bg_no);
   dev->setValue(WSDEV_BACK_PIXMAP,(void*)&_bp_no);
 
-  char pixmap_style = _pixmap_style;
+  char pixmap_style = getPixmapStyle();
   dev->setValue(WSDEV_PIXMAP_STYLE,(void*)&pixmap_style);
   if (_title_string != NULL){
     dev->setValue(WSDEV_TITLE_STRING,(void*)_title_string);
@@ -553,7 +555,7 @@ long WSCwindow::cdraw(){
   if (getVisible() == False){
     return WS_ERR;
   }
-  if (_pixmap_style != WS_DIRECT_WINDOW){
+  if (getPixmapStyle() != WS_DIRECT_WINDOW){
     redraw();
   }else{
     WSCrect area;
@@ -572,11 +574,14 @@ long WSCwindow::cdraw(){
   return WS_NO_ERR;
 }
 long WSCwindow::draw(){
+dbprintf("WSCwindow::draw %s:%d %s begin..\n",__FILE__,__LINE__,getInstanceName());
   if (getVisible() == False){
+dbprintf("WSCwindow::draw %s:%d %s vis=False\n",__FILE__,__LINE__,getInstanceName());
     return WS_NO_ERR;
   }
   WSDdev* dev = getowndev();
   if (dev == NULL){
+dbprintf("WSCwindow::draw %s:%d %s dev=NULL\n",__FILE__,__LINE__,getInstanceName());
     return WS_ERR;
   }
   WSCbool absolute = getAbsoluteDraw(); 
@@ -592,18 +597,24 @@ long WSCwindow::draw(){
     }else{
 #endif
       if ( dev->isExposed(0,0,_w,_h) == False ){
+dbprintf("WSCwindow::draw %s:%d %s not exposed\n",__FILE__,__LINE__,getInstanceName());
         return WS_NO_ERR;
       }
 #if 0
     }
 #endif
   }
+  if (_update_resize != False){
+    _update_resize = False;
+    execResizeEvent();
+  }
 
   if (_geometry_changed != False){
     _exec_child_adjust_for_anchors();
   }
   long err = dev->beginDraw(0,0,_w,_h,absolute);
   if (err != WS_NO_ERR){
+dbprintf("WSCwindow::draw %s:%d %s not ready\n",__FILE__,__LINE__,getInstanceName());
       return WS_NO_ERR;
   }
   short ex = 0;
@@ -737,7 +748,7 @@ void WSCwindow::onResize(WSCrect* area){
   }
   if (fl != False){
     WSDdev* dev = getowndev();
-    if (dev != NULL || _pixmap_style != WS_DIRECT_WINDOW){
+    if (dev != NULL || getPixmapStyle() != WS_DIRECT_WINDOW){
       dev->setValue(WSDEV_WIDTH,&_w);
       dev->setValue(WSDEV_HEIGHT,&_h);
     }
@@ -750,13 +761,19 @@ void WSCwindow::onResize(WSCrect* area){
     long i;
     for(i=0; i<num; i++){
       WSCbase* child = (WSCbase*)children[i];
+dbprintf("WSCwindow::onResize %s:%d %s child=%s call adjust_for_anchors\n",__FILE__,__LINE__,getInstanceName(),child->getInstanceName());
       child->_adjust_for_anchors(_w,_h);
+      if (getPixmapStyle() == WS_DYNAMIC_PIXMAP){
+        if (child->isNeedUpdate() != False){
+          child->update();
+dbprintf("WSCwindow::onResize %s:%d %s child=%s call update\n",__FILE__,__LINE__,getInstanceName(),child->getInstanceName());
+        }
+      }
     }
   }
 }
 
 void WSCwindow::onVisibleChange(WSCbool fl){
-//printf("WSCwinodw::onVisibleChange %s %d\n",getInstanceName(),fl);
   long need_resize_event = 0;
   if (fl != False && getowndev() == NULL){
     need_resize_event = 1;
@@ -807,7 +824,9 @@ void WSCwindow::onVisibleChange(WSCbool fl){
           }
         }
         if (no_exit == 0){
-          exit(0);
+          if (WSGIappDev()->getMode() == WS_MODE_NORMAL){
+            exit(0);
+          }
         }
       }
     }
@@ -831,7 +850,14 @@ void WSCwindow::update(){
       long i;
       for(i=0; i<num; i++){
         WSCbase* child = (WSCbase*)children[i];
+dbprintf("WSCwindow::onResize %s:%d %s child=%s call adjust_for_anchors\n",__FILE__,__LINE__,getInstanceName(),child->getInstanceName());
         child->_adjust_for_anchors(_w,_h);
+        if (getPixmapStyle() == WS_DYNAMIC_PIXMAP){
+          if (child->isNeedUpdate() != False){
+            child->update();
+dbprintf("WSCwindow::onResize %s:%d %s child=%s call update\n",__FILE__,__LINE__,getInstanceName(),child->getInstanceName());
+          }
+        }
       }
     }
     redraw();
@@ -969,7 +995,18 @@ void WSCwindow::_exec_child_adjust_for_anchors(){
       long i;
       for(i=0; i<num; i++){
         WSCbase* child = (WSCbase*)children[i];
+dbprintf("WSCwindow::onResize %s:%d %s child=%s call adjust_for_anchors\n",__FILE__,__LINE__,getInstanceName(),child->getInstanceName());
         child->_adjust_for_anchors(_w,_h);
+        if (getPixmapStyle() == WS_DYNAMIC_PIXMAP){
+          if (child->isNeedUpdate() != False){
+            if ((long)child->getUserData("anchor update..") == 0){
+dbprintf("WSCwindow::onResize %s:%d %s child=%s call update\n",__FILE__,__LINE__,getInstanceName(),child->getInstanceName());
+              child->setUserData("anchor update..",(void*)1);
+              child->update();
+              child->setUserData("anchor update..",(void*)0);
+            }
+          }
+        }
       }
     }
   }
@@ -1015,4 +1052,34 @@ long WSCwindow::execEventProc(long ev, void* data){
   }
   return WSCbase::execEventProc(ev,data);
 }
-
+long WSCwindow::getPixmapStyle(){
+#ifndef BTRON
+#ifndef TE
+  return _pixmap_style;
+#else
+  return WS_DYNAMIC_PIXMAP;
+#endif
+#else
+  return WS_DYNAMIC_PIXMAP;
+#endif
+}
+void WSCwindow::_delay_visible(unsigned char,void* ptr){
+  WSCbase* win = (WSCbase*)ptr;
+  WSCbool fl = WSGIappObjectList()->existInstance(win);
+  if (fl != False){
+    win->WSCbase::setVisible(True);
+  }
+}
+void WSCwindow::setVisible(WSCbool fl){
+  if (_vis_ch_sequence != False){
+    if (_vis == False && fl != False){
+      WSGIappTimer()->addTriggerProc(_delay_visible,WS250MS,(WSCbase*)this);
+      return;
+    }
+    WSCbase::setVisible(fl);
+    return;
+  }
+  _vis_ch_sequence = True;
+  WSCbase::setVisible(fl);
+  _vis_ch_sequence = False;
+}
