@@ -80,6 +80,7 @@ FILE* _ws_debug_fp = NULL;
 //FILE* _ws_debug_fp = stdout;
 #endif
 static WSCbool _ws_mem_debug_ = False;
+static WSCbool _ws_mem_debug2_ = False;
 int _dbprintf_init(){
   if (getenv("WSDEBUG") != NULL && _ws_debug_fp == NULL){
 #ifndef BTRON
@@ -88,15 +89,34 @@ int _dbprintf_init(){
     _ws_debug_fp = stdout;
 #endif
   }
+#ifdef TE
+  if (fopen("/SYS/.wsdebug","r")){
+    _ws_debug_fp = stdout;
+  }
+#endif
   if (getenv("WSMEMDEBUG") != NULL){
     _ws_mem_debug_ = True;
   }
+  if (getenv("WSMEMDEBUG2") != NULL){
+    _ws_mem_debug2_ = True;
+  }
   return 0;
 };
 int _dbprintf(const char* format,...){
   if (_ws_debug_fp == NULL){
     return -1;
   }
+  if (_ws_mem_debug2_ == True){
+    int i;
+    void* ptr[10];
+    for(i=0; i<10;i++){
+      ptr[i] = malloc(i*1000);
+      memset(ptr[i],0,i*1000);
+    }
+    for(i=0; i<10;i++){
+      free(ptr[i]);
+    }
+  }else
   if (_ws_mem_debug_ == True){
     int i;
     void* ptr[100];
@@ -286,12 +306,12 @@ void WSGFcleanupStretchAction(WSCbase* obj){
   if (stimer != NULL){
     delete stimer;
   }
-  WSDprivateTimer* stimer2 = (WSDprivateTimer*)obj->getUserData("stretch-timer");
+  obj->setUserData("stretch-timer",NULL);
+  WSDprivateTimer* stimer2 = (WSDprivateTimer*)obj->getUserData("stretch-timer2");
   if (stimer2 != NULL){
     delete stimer2;
   }
 
-  obj->setUserData("stretch-timer",NULL);
   obj->setUserData("stretch-timer2",NULL);
 }
 void WSGFgetAllPropertyList(WSCbase* client,WSClistData* out){
@@ -365,7 +385,7 @@ long WSGFsendMessage(char* message,char* data){
   while(1){
     strncpy(buf,&data[ptr],WS_SEND_LEN);
     buf[WS_SEND_LEN] = 0;
-printf("WSGFsendMessage send:#%s#\n",buf);
+//printf("WSGFsendMessage send:#%s#\n",buf);
     WSDmessage::extSendMessage(NULL,message,buf);
     ptr+= WS_SEND_LEN;
     if (ptr+1 > len){
@@ -733,9 +753,9 @@ long WSGFreplaceFile(char* lstr,void* data,long len,WSCbool same_save){
     sprintf(bkbuf,"%s.bak",(char*)str);
     if ( WSGIappFileSystem()->rename(str,bkbuf) == WS_ERR){
 #ifdef MSW
-printf("ERROR WSGFreplaceFile()  cannot rename filename %s\n",(char*)str);
+      printf("ERROR WSGFreplaceFile()  cannot rename filename %s\n",(char*)str);
 #else
-fprintf(stderr,"ERROR WSGFreplaceFile()  cannot rename filename %s\n",(char*)str);
+      fprintf(stderr,"ERROR WSGFreplaceFile()  cannot rename filename %s\n",(char*)str);
 #endif
       return WS_ERR;
     }
@@ -750,9 +770,9 @@ fprintf(stderr,"ERROR WSGFreplaceFile()  cannot rename filename %s\n",(char*)str
   }else{
     delete file;
 #ifdef MSW
-printf("ERROR WSGFreplaceFile()  cannot open filename %s\n",(char*)str);
+    printf("ERROR WSGFreplaceFile()  cannot open filename %s\n",(char*)str);
 #else
-fprintf(stderr,"ERROR WSGFreplaceFile()  cannot open filename %s\n",(char*)str);
+    fprintf(stderr,"ERROR WSGFreplaceFile()  cannot open filename %s\n",(char*)str);
 #endif
     return WS_ERR; 
   }
