@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -32,6 +32,7 @@
 #include <WSDmouse.h>
 #include <WSCfontSet.h>
 #include <WSCcolorSet.h>
+#include <WSCbaseList.h>
 #include <WSDappDev.h>
 #include <WSDkeyboard.h>
 #include <string.h>
@@ -41,33 +42,6 @@
 
 WSMFguiClassInitialize(WSCpulldownMenuPopup, WSCwindow);
 
-struct WSCpulldownData {
-  WSCstring  _label;
-  WSCstring  _op;
-  WSCstring  _sc;
-  WSCpulldownData*  _next;
-  WSCpulldownData*  _cascade_data;
-  short _id;
-  WSCbool    _separator;
-  WSCbool    _cascaded;
-  WSCbool    _sensitive;
-public:
-  WSCpulldownData();
-  ~WSCpulldownData();
-  WSCbool   getSensitive(long no);
-  WSCbool   getSensitiveWithId(long id);
-  WSCpulldownData* getItem(long no);
-  WSCpulldownData* getItemWithId(long no);
-  long   setSensitive(long no,WSCbool fl );
-  long   setSensitiveWithId(long id,WSCbool fl );
-  void   setCascaded(WSCbool fl);
-  void   add(WSCpulldownData* data);
-  long   getItems();
-
-  static  WSCpulldownData* parse(char* menu_string);
-
-};
-
 WSCpulldownData::WSCpulldownData(){
   _id = -1;
   _separator = 0;
@@ -212,7 +186,7 @@ WSCpulldownData* WSCpulldownData::parse(char* menu_string){
             tmp.deleteChars(0,wpos);
             wpos = tmp.getWordCharPos(1,"{");
             tmp.deleteChars(0,wpos);
-            char* tstr = tmp.getString();
+            char* tstr = tmp.getString(WS_EN_UTF8);
             long len = strlen(tstr);
             long num_of_conma = 0;
             long j;
@@ -236,7 +210,8 @@ WSCpulldownData* WSCpulldownData::parse(char* menu_string){
             }
 
             tstr[j] = 0;
-            data->_op.setString(tstr);
+            WSCstring t(tstr,WS_EN_UTF8);
+            data->_op.setString(t.getString());
             data->setCascaded(True);
           }else{
             data->_op.setString(opstr.getString());
@@ -280,6 +255,7 @@ WSCpulldownMenuPopup::WSCpulldownMenuPopup(WSCbase* base, char* objname):
   _ts_no = WS_DF_MENUTOPSHADOWCOLOR;
   _bs_no = WS_DF_MENUBOTTOMSHADOWCOLOR;
 
+  WSGIappObjectList()->addEvent(this,WSEV_GUI_POLICY_CH);
 
   WSMFpropertyCreateStart
   
@@ -345,6 +321,8 @@ long WSCpulldownMenuPopup::initialize(){
 }
 
 WSCpulldownMenuPopup::~WSCpulldownMenuPopup(){
+  WSGIappObjectList()->delEvent(this,WSEV_GUI_POLICY_CH);
+
   long num = _child_pld_list.getNum();
   long i;
   for(i=0; i <num; i++){
@@ -359,7 +337,7 @@ WSCpulldownMenuPopup::~WSCpulldownMenuPopup(){
 }
 
 void WSCpulldownMenuPopup::onResize(WSCrect* rect){
-printf("WSCpulldownMenuPopup::onResize %d,%d,%d,%d XXZZy16\n",rect->x,rect->y,rect->width,rect->height);
+//printf("WSCpulldownMenuPopup::onResize %d,%d,%d,%d XXZZy16\n",rect->x,rect->y,rect->width,rect->height);
 }
 long WSCpulldownMenuPopup::_device_initialize(){
   WSCwindow::_device_initialize();
@@ -393,6 +371,50 @@ long WSCpulldownMenuPopup::draw(){
   if (absolute == False && dev->isExposed(0, 0, w, h) == False){
     return WS_NO_ERR;
   }
+  if (WSGIappDev()->getExtGuiPolicySelected() != False){
+    if (_ext_draw_proc == NULL){
+      _ext_draw_proc = (void(*)(void*))WSGIappDev()->
+                               getExtGuiPolicyProc("WSCpulldownMenuPopup::draw");
+    }
+    if (_ext_draw_proc != NULL){
+      WSCpulldownMenuPopup_draw_struct st;
+      st._this = this;
+      st.dev = dev;
+      st.x = _x;
+      st.y = _y;
+      st.width = _w;
+      st.height = _h;
+      st.shadow_thickness = _shadow_thick;
+      st.shadow_type = _shadow_type;
+      st.fore_color = _fg_no;
+      st.back_color = _bg_no;
+      st.top_shadow_color = _ts_no;
+      st.bottom_shadow_color = _bs_no;
+      st.back_pixmap = _bp_no;
+      st.gradation = _grad_no;
+      st.gradation_margin = _grad_margin;
+      st.menu_string = _menu_string;
+      st.item_height = _item_height;
+      st.prc_name = _prc_name;
+      st.id_value = _id_value;
+      st.selected_item = _selected_item;
+      st.items = _items;
+      st.font =  _font;
+      st.selected = _selected;
+      st.next_popup = _next_popup;
+      st.emboss = _emboss;
+      st.mouse_no_check = _mouse_no_check;
+      st.wait_child_popup = _wait_child_popup;
+      st.child_popup_waited = _child_popup_waited;
+
+      _ext_draw_proc(&st);
+
+      updateChild();
+      _mouse_no_check = 0;
+
+      return WS_NO_ERR;
+    }
+  }
   WSCushort st = _shadow_thick;
 
   if (st > 0){
@@ -477,7 +499,6 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
               py < y + posy + _item_height && _mouse_no_check == 0) ||
              (_mouse_no_check != 0 && cnt == _selected_item) ){
 
-//          if (pld->getSensitiveWithId(itemid) != False){ 
           if (own_pld->getSensitive(cnt) != False){ 
             if (WSGIappDev()->getGuiPolicy() & WS_POLICY_WINDOWS){
               dev->setHatchPattern(0);
@@ -489,7 +510,6 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
         }
 
         dev->setForeColor(_fg_no);
-//        if ( pld->getSensitiveWithId(itemid) == False) {
         if ( own_pld->getSensitive(cnt) == False) {
           if (getEmboss() != False){
             dev->setForeColor(_ts_no);
@@ -501,7 +521,6 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
           dev->setHatchPattern(0);
         }
 
-//        if (getEmboss() != False && pld->getSensitiveWithId(itemid) == False){
         if (getEmboss() != False && own_pld->getSensitive(cnt) == False){
           dev->setForeColor(_bs_no);
         }else{
@@ -511,7 +530,6 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
               py < y + posy + _item_height && _mouse_no_check == 0) ||
              (_mouse_no_check != 0 && cnt == _selected_item) ){
 
-//          if (pld->getSensitiveWithId(itemid) != False){ 
           if (own_pld->getSensitive(cnt) != False){ 
             if (WSGIappDev()->getGuiPolicy() & WS_POLICY_WINDOWS){
               dev->setForeColor(WSGIappColorSet()->getDefaultColorNo(WS_DF_MENUSELECTFORECOLOR));
@@ -526,7 +544,6 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
               py < y + posy + _item_height && _mouse_no_check == 0) ||
              (_mouse_no_check != 0 && cnt == _selected_item) ){
 
-//          if (pld->getSensitiveWithId(itemid) != False){
           if (own_pld->getSensitive(cnt) != False){
             _selected_item = cnt;
             if (WSGIappDev()->getGuiPolicy() & WS_POLICY_ORIGINAL){
@@ -574,7 +591,7 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
             tmp.deleteChars(0,wpos);
             wpos = tmp.getWordCharPos(1,"{");
             tmp.deleteChars(0,wpos);
-            char* tstr = tmp.getString();
+            char* tstr = tmp.getString(WS_EN_UTF8);
             long len = strlen(tstr);
             long num_of_conma = 0;
             long j;
@@ -599,7 +616,8 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
             i += num_of_conma;
             if (_wait_child_popup == 0){
               if (own_pld->getSensitive(cnt) != False){
-                popupChildPld(child_cnt,tstr,x+w,y+posy);
+                WSCstring t(tstr,WS_EN_UTF8);
+                popupChildPld(child_cnt,t.getString(),x+w,y+posy);
               }
             }else{
               _child_popup_waited = True;
@@ -607,7 +625,6 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
             child_cnt++;
 
           }else{
-//            if ( checkChildStatus() == False  && pld->getSensitiveWithId(itemid) != False) {
             if ( checkChildStatus() == False  && own_pld->getSensitive(cnt) != False) {
               target->_prc_name.setString( item_prc_name.getString() );
               target->_selected = True;
@@ -657,7 +674,7 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
             tmp.deleteChars(0,wpos);
             wpos = tmp.getWordCharPos(1,"{");
             tmp.deleteChars(0,wpos);
-            char* tstr = tmp.getString();
+            char* tstr = tmp.getString(WS_EN_UTF8);
             long len = strlen(tstr);
             long num_of_conma = 0;
             long j;
@@ -751,7 +768,7 @@ void WSCpulldownMenuPopup::popupChildPld(short childnum,char* menustr,short x,sh
         tmp.deleteChars(0,wpos);
         wpos = tmp.getWordCharPos(1,"{");
         tmp.deleteChars(0,wpos);
-        char* tstr = tmp.getString();
+        char* tstr = tmp.getString(WS_EN_UTF8);
         long len = strlen(tstr);
         long num_of_conma = 0;
         long j;
@@ -1091,3 +1108,45 @@ void WSCpulldownMenuPopup::onKeyPress(WSDkeyboard* keyboard,WSCbool fl){
 void WSCpulldownMenuPopup::setSelected(WSCbool fl){
   _selected = fl;
 }
+
+void(*WSCpulldownMenuPopup::_ext_draw_proc)(void*) = NULL;
+WSCstring WSCpulldownMenuPopup::_policy_name;
+
+void WSCpulldownMenuPopup::onGuiPolicyChange(long policy){
+  WSCbase::onGuiPolicyChange(policy);
+  if (WSGIappDev()->getExtGuiPolicySelected() == False){
+    _ext_draw_proc = NULL;
+  }else{
+    if (!strcmp((char*)_policy_name,(char*)WSGIappDev()->getExtGuiPolicyName())){
+    }else{
+      _ext_draw_proc = (void(*)(void*))WSGIappDev()->getExtGuiPolicyProc("WSCpulldownMenuPopup::draw");
+    }
+  }
+  needUpdate();
+  setAbsoluteDraw(True);
+  redraw();
+}
+void WSCpulldownMenuPopup::set_items(long items){
+  _items = items;
+}
+void WSCpulldownMenuPopup::set_selected(WSCbool fl){
+  _selected = fl;
+}
+void WSCpulldownMenuPopup::set_selected_item(long item){
+  _selected_item = item;
+}
+WSCstring& WSCpulldownMenuPopup::get_prc_name(){
+  return _prc_name;
+}
+WSClistData& WSCpulldownMenuPopup::get_child_pld_list(){
+  return _child_pld_list;
+}
+void* WSCpulldownMenuPopup::get_pld_data(){
+  return _pld_data;
+}
+void WSCpulldownMenuPopup::set_child_popup_waited(WSCbool fl){
+  _child_popup_waited = fl;
+}
+void WSCpulldownMenuPopup::set_id_value(long v){
+  _id_value = v;
+}
