@@ -150,11 +150,16 @@ void WSCsform::_parse_pos(char* pos){
 
   long num = str.getWords(_separator);
   long i;
+  long pre = 0;
   for(i=0; i<num; i++){
     WSCstring n;
     n = str.getWord(i,_separator);
     long item = atoi(n);
+    if (item < pre){
+      item = pre + _minimum;
+    }
     _pos_list.add((void*)item);
+    pre = item;
 //printf("WSCsform::_parse_pos %d pos=%d\n",i,item);
   }
 }
