@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -440,6 +440,7 @@ WSCbool WSCvifield::getCursorFore(){
 }
 
 void WSCvifield::setCursorFore(WSCbool fl){
+//printf("WSCvifield::setCursorFore fl=%d\n",fl);
   if (fl != False){
     _cursor_fore = True;
   }else{
@@ -483,7 +484,7 @@ void WSCvifield::_fill_space(){
 
 long WSCvifield::draw(){
 #ifdef TDBG
-printf("WSCvifield::draw start %d\n",WSGFclocktime());
+  printf("WSCvifield::draw start %d\n",WSGFclocktime());
 #endif
 dbprintf("WSCvifield::draw %s:%d  %s begin..\n",__FILE__,__LINE__,getInstanceName());
   if (getVisible() == False){
@@ -520,7 +521,7 @@ dbprintf("WSCvifield::draw %s:%d  %s dev=NULL\n",__FILE__,__LINE__,getInstanceNa
   }
 
 #ifdef TDBG
-printf("WSCvifield::draw here-1 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here-1 %d\n",WSGFclocktime());
 #endif
 
   short x = _x;
@@ -577,7 +578,7 @@ dbprintf("WSCvifield::draw %s:%d %s device is not ready\n",__FILE__,__LINE__,get
   str[ulen] = 0;
  
 #ifdef TDBG
-printf("WSCvifield::draw here0 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here0 %d\n",WSGFclocktime());
 #endif
 
   if (shadowtype != WS_SHADOW_TRANS) {
@@ -686,7 +687,7 @@ dbprintf("WSCvifield::draw %s:%d %s draw shadow..\n",__FILE__,__LINE__,getInstan
   }
 
 #ifdef TDBG
-printf("WSCvifield::draw here1 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here1 %d\n",WSGFclocktime());
 #endif
 
   if (!(bldraw  && blinktype != WS_BACK && twinblink == False)){
@@ -722,9 +723,9 @@ printf("WSCvifield::draw here1 %d\n",WSGFclocktime());
     if ( draw_cur != False){
       long cpos = _cur_pos - _cbase;
 #ifdef TDBG
-printf("WSCvifield::draw here1.5 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here1.5 %d\n",WSGFclocktime());
 #endif
-//printf("WSCvifield::draw drawUString xy=%d,%d\n",sx,sy);
+//printf("WSCvifield::draw drawUString xy=%d,%d cpos=%d _cursor_fore=%d\n",sx,sy,cpos,_cursor_fore);
       if (_multi_lines == False){
         if (_key_input_disable == False){
           dev->drawUString(sx,sy,sw,sh,
@@ -756,7 +757,7 @@ dbprintf("WSCvifield::draw %s:%d %s draw string..\n",__FILE__,__LINE__,getInstan
         WSDfont* font = WSGIappFontSet()->getFont(_font);
         long fh = font->getFontHeight();
 #ifdef TDBG
-printf("WSCvifield::draw here2 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here2 %d\n",WSGFclocktime());
 #endif
 
         if (_no_mcur_adjust == 0){
@@ -786,7 +787,7 @@ printf("WSCvifield::draw here2 %d\n",WSGFclocktime());
         }
 dbprintf("WSCvifield::draw %s:%d %s draw string..\n",__FILE__,__LINE__,getInstanceName());
 #ifdef TDBG
-printf("WSCvifield::draw here3 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here3 %d\n",WSGFclocktime());
 #endif
       }
 #if 0
@@ -819,7 +820,7 @@ printf("WSCvifield::draw here3 %d\n",WSGFclocktime());
         WSDfont* font = WSGIappFontSet()->getFont(_font);
         long fh = font->getFontHeight();
 #ifdef TDBG
-printf("WSCvifield::draw here2 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here2 %d\n",WSGFclocktime());
 #endif
         if (_no_mcur_adjust == 0){
 //printf("WSCvifield::draw here3 yy=%d _my=%d fh=%d sh=%d mdy=%d ",yy,_my,fh,sh,mdy);
@@ -841,7 +842,7 @@ printf("WSCvifield::draw here2 %d\n",WSGFclocktime());
         dev->drawUString(x1,y1,sw2,sh2, str, _font, alignment, -1,False,
                spos1,spos2);
 #ifdef TDBG
-printf("WSCvifield::draw here3 %d\n",WSGFclocktime());
+  printf("WSCvifield::draw here3 %d\n",WSGFclocktime());
 #endif 
 
       }
@@ -861,7 +862,7 @@ dbprintf("WSCvifield::draw %s:%d %s draw string..\n",__FILE__,__LINE__,getInstan
 dbprintf("WSCvifield::draw %s:%d  %s end..\n",__FILE__,__LINE__,getInstanceName());
   dev->endDraw();
 #ifdef TDBG
-printf("WSCvifield::draw done %d\n",WSGFclocktime());
+  printf("WSCvifield::draw done %d\n",WSGFclocktime());
 #endif 
   return WS_NO_ERR;
 }
@@ -894,7 +895,7 @@ long WSCvifield::_cursor_move(char direction){
     return WS_NO_ERR;
   }else if (direction == WS_UP){
 #ifdef TDBG
-printf("WSCvifield::_cursor_move start %d\n",WSGFclocktime());
+  printf("WSCvifield::_cursor_move start %d\n",WSGFclocktime());
 #endif 
     long xpos,ypos;
 //    WSCushort* text = _get_disp_string();
@@ -919,12 +920,12 @@ printf("WSCvifield::_cursor_move start %d\n",WSGFclocktime());
     }
 
 #ifdef TDBG
-printf("WSCvifield::_cursor_move done %d\n",WSGFclocktime());
+  printf("WSCvifield::_cursor_move done %d\n",WSGFclocktime());
 #endif
     return WS_NO_ERR;
   }else if (direction == WS_DOWN){
 #ifdef TDBG
-printf("WSCvifield::_cursor_move start %d\n",WSGFclocktime());
+  printf("WSCvifield::_cursor_move start %d\n",WSGFclocktime());
 #endif
     long xpos,ypos;
 //    WSCushort* text = _get_disp_string();
@@ -935,14 +936,14 @@ printf("WSCvifield::_cursor_move start %d\n",WSGFclocktime());
 //long _must_adjust_x_2;
     WSGFcalcStringXYPos(text,_cur_pos,&xpos,&ypos);
 #ifdef TDBG
-printf("WSCvifield::_cursor_move here2 %d\n",WSGFclocktime());
+  printf("WSCvifield::_cursor_move here2 %d\n",WSGFclocktime());
 #endif
     if (_lines == -1 ){
       _lines = WSGFgetLinesUCS2(_ucs2);
 //printf("WSCvifield::_cursor_move here lines=%d _cbase=%d\n",_lines,_cbase);
     }
 #ifdef TDBG
-printf("WSCvifield::_cursor_move here3 %d\n",WSGFclocktime());
+  printf("WSCvifield::_cursor_move here3 %d\n",WSGFclocktime());
 #endif
     if (_enable_focus_move != False && ypos >  _lines-2 ){
       return WS_ERR;
@@ -958,7 +959,7 @@ fflush(stdout);
       _cur_pos = _max_length - !_icursor;
     }
 #ifdef TDBG
-printf("WSCvifield::_cursor_move done %d\n",WSGFclocktime());
+  printf("WSCvifield::_cursor_move done %d\n",WSGFclocktime());
 #endif
     return WS_NO_ERR;
   }
@@ -976,7 +977,7 @@ void WSCvifield::_get_disp_cur_pos(long* cx,long* cy){
   }
 
 #ifdef TDBG
-printf("WSCvifield::_get_disp_cur_pos start %d\n",WSGFclocktime());
+  printf("WSCvifield::_get_disp_cur_pos start %d\n",WSGFclocktime());
 #endif
 
   _cur_pos_bk = _cur_pos;
@@ -1030,7 +1031,7 @@ printf("WSCvifield::_get_disp_cur_pos start %d\n",WSGFclocktime());
   *cy = _disp_cur_y;
 
 #ifdef TDBG
-printf("WSCvifield::_get_disp_cur_pos done %d\n",WSGFclocktime());
+  printf("WSCvifield::_get_disp_cur_pos done %d\n",WSGFclocktime());
 #endif
 
 //printf("WSCvifield::_get_disp_cur_pos4 %d %d\n",_disp_cur_x,_disp_cur_y);
@@ -1299,7 +1300,7 @@ void WSCvifield::_adjust_max_len(){
 }
 void WSCvifield::_on_key_input(WSDkeyboard* keyboard,WSCbool fl){
 #ifdef TDBG
-printf("WSCvifield::_on_key_input %d\n",WSGFclocktime());
+  printf("WSCvifield::_on_key_input %d\n",WSGFclocktime());
 #endif
   if (getSensitive() == False){
     return;
@@ -1731,7 +1732,7 @@ printf("WSCvifield::_on_key_input %d\n",WSGFclocktime());
     redraw();
   }
 #ifdef TDBG
-printf("WSCvifield::_on_key_input done. %d\n",WSGFclocktime());
+  printf("WSCvifield::_on_key_input done. %d\n",WSGFclocktime());
 #endif
 }
 void WSCvifield::replaceSelectedString(char* istr,long encode){
@@ -1806,7 +1807,7 @@ void WSCvifield::_replace_string(WSCushort* istr){
 }
 void WSCvifield::_get_cur_pos(long* cx,long* cy,long* cpos){
 #ifdef TDBG
-printf("WSCvifield::_get_cur_pos  start  -------    %d\n",WSGFclocktime());
+  printf("WSCvifield::_get_cur_pos  start  -------    %d\n",WSGFclocktime());
 #endif
   if (_multi_lines == False){
     *cx = _cur_pos;
@@ -1837,7 +1838,7 @@ printf("WSCvifield::_get_cur_pos  start  -------    %d\n",WSGFclocktime());
     *cy = line;
   }
 #ifdef TDBG
-printf("WSCvifield::_get_cur_pos  done.  -------    %d\n",WSGFclocktime());
+  printf("WSCvifield::_get_cur_pos  done.  -------    %d\n",WSGFclocktime());
 #endif
 }
 WSCbool WSCvifield::_return_key_ok(){
@@ -1907,7 +1908,7 @@ WSCushosrt* WSCvifield::_get_disp_string(){
 #endif
 void WSCvifield::_fep_cursor_adjust(WSDkeyboard* keyboard){
 #ifdef TDBG
-printf("WSCvifield::_fep_cursor_adjust start %d\n",WSGFclocktime());
+  printf("WSCvifield::_fep_cursor_adjust start %d\n",WSGFclocktime());
 #endif
   long ox,oy;
   if (getowndev() != NULL){
@@ -1923,7 +1924,7 @@ printf("WSCvifield::_fep_cursor_adjust start %d\n",WSGFclocktime());
     }
   }
 #ifdef TDBG
-printf("WSCvifield::_fep_cursor_adjust done %d\n",WSGFclocktime());
+  printf("WSCvifield::_fep_cursor_adjust done %d\n",WSGFclocktime());
 #endif
 }
 
@@ -1948,9 +1949,10 @@ void WSCvifield::onFocusChange(WSCbool fl){
     }
     if (_cur_timer_id != 0){
 WSMFtrace("WSCvifiled::onFocusChange(%d)   _cur_timer_id ERROR!!!!\n",fl);
+    }else{
+      _cur_timer_id = WSGIappTimer()->addTimerProc(_cursor_blink_handler,WS500MS,this);
+      setCursorFore(True);
     }
-    _cur_timer_id = WSGIappTimer()->addTimerProc(_cursor_blink_handler,WS500MS,this);
-    setCursorFore(True);
     _fep_cursor_adjust(WSGIappKeyboard());
 
     if (_kanji_in != False && _fep_set_focus != False){
@@ -1972,6 +1974,7 @@ WSMFtrace("WSCvifiled::onFocusChange(%d)   _cur_timer_id ERROR!!!!\n",fl);
     WSGIappKeyboard()->resetFocusInputWorkProc();
     WSGIappTimer()->delTimerProc( _cur_timer_id );
     _cur_timer_id = 0;
+    setCursorFore(False);
     if (_return_key_focus != False){
       setSpecialFocus(False);
       WSGIappKeyboard()->resetSpecialInputWorkProc();
@@ -2266,3 +2269,57 @@ void WSCvifield::onParentVisibleChange(WSCbool fl){
   }
   WSCvlabel::onParentVisibleChange(fl);
 }
+void WSCvifield::onWindowFocusChange(WSCbool fl){
+  if (fl == False && _use_pix == False && _dev != NULL){
+    char fl = False;
+    _dev->setValue(WSDEV_USE_PIXMAP,&fl);
+  }
+  if (fl != False){
+    WSGIappKeyboard()->setFocusInputWorkProc(_key_handler,NULL,this);
+    if (_return_key_focus != False){
+      WSGIappKeyboard()->setSpecialInputWorkProc(_special_key_handler,this);
+    }
+    if (_kanji_in == False){
+      WSGIappKeyboard()->setEnableFep(getowndev(),False);
+    }else{
+      WSGIappKeyboard()->setEnableFep(getowndev(),True);
+    }
+    if (_cur_timer_id != 0){
+WSMFtrace("WSCvifiled::onWindowFocusChange(%d)   _cur_timer_id ERROR!!!!\n",fl);
+    }else{
+      _cur_timer_id = WSGIappTimer()->addTimerProc(_cursor_blink_handler,WS500MS,this);
+      setCursorFore(True);
+    }
+    _fep_cursor_adjust(WSGIappKeyboard());
+
+    if (_kanji_in != False && _fep_set_focus != False){
+      _fep_set_focus = False;
+      long ox,oy;
+      if (_multi_lines == False){
+        _get_disp_cur_pos(&ox,&oy);
+        WSGIappKeyboard()->startKanji(getowndev(),ox + _x,oy + _y,_font,_fore_color,
+                          _back_color);
+      }else{
+        _get_disp_cur_pos(&ox,&oy);
+        WSGIappKeyboard()->startKanji(getowndev(),_shadow_thick + ox + _x - _mx,
+                          _shadow_thick + oy + _y - _my,_font,
+                          _fore_color,_back_color);
+      }
+    }
+
+  }else{
+    WSGIappKeyboard()->resetFocusInputWorkProc();
+    WSGIappTimer()->delTimerProc( _cur_timer_id );
+    _cur_timer_id = 0;
+    setCursorFore(False);
+    if (_return_key_focus != False){
+      WSGIappKeyboard()->resetSpecialInputWorkProc();
+    }
+  }
+  setAbsoluteDraw(True);
+  draw();
+
+  if (fl == False && getowndev() != NULL){
+    WSGIappKeyboard()->resetFep(getowndev());
+  }
+}
