@@ -104,7 +104,7 @@ WSDbtronDraw::WSDbtronDraw(){
 WSDbtronDraw::~WSDbtronDraw(){}
 
 long WSDbtronDraw::setForeColor(short cno){
-  W ret = _fg_value;
+  short ret = _fg_cno;
   if (_fg_cno != cno){
     _fg_col = WSGIappColorSet()->getColor(cno);
     if (_fg_col != NULL){
@@ -120,7 +120,7 @@ long WSDbtronDraw::setForeColor(short cno){
 }
 
 long WSDbtronDraw::setBackColor(short cno){
-  W ret = _fg_value;
+  short ret = _bg_cno;
   if (_bg_cno != cno){
     _bg_col = WSGIappColorSet()->getColor(cno);
     if (_bg_col != NULL){
@@ -135,7 +135,7 @@ long WSDbtronDraw::setBackColor(short cno){
   return (long)ret;
 }
 long WSDbtronDraw::setForeColor(WSDcolor* color){
-  W bk = _fg_cno;
+  short bk = _fg_cno;
   if (color == NULL){
     return bk;
   }
@@ -151,7 +151,7 @@ long WSDbtronDraw::setForeColor(WSDcolor* color){
 }
 
 long WSDbtronDraw::setBackColor(WSDcolor* color){
-  W bk = _bg_cno;
+  short bk = _bg_cno;
   if (color == NULL){
     return bk;
   }
@@ -871,16 +871,12 @@ dbprintf(">> WSDbtronDraw::drawImage mem_gid1=0x%x\n",mem_gid1);
     xoff = ((short)w - (short)pw);
     yoff = ((short)h - (short)ph);
   }
-  if ((long)mem_gid1 == -1 && mem_gid1 != 0){
+  if ((long)mem_gid1 == -1 || mem_gid1 == 0){
     return WS_NO_ERR;
   }
-  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
-dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
-#if 0
-    XSetClipMask(_display,_gc,pix2);
-    XSetClipOrigin(_display,_gc,x+xoff,y+yoff);
-#endif
-  }
+//  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
+//dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
+//  }
   short px,py;
   if (_fdev != NULL){
     _fdev->getAbstPos(&px,&py);
@@ -894,6 +890,21 @@ dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
   long dw,dh;
   WSGFandArea(x,y,w,h,_clip_x-px,_clip_y-py,_clip_w,_clip_h,&dx1,&dy1,(WSCulong*)&dw1,(WSCulong*)&dh1);
   WSGFandArea(dx1,dy1,dw1,dh1,x+xoff,y+yoff,pw,ph,&dx,&dy,(WSCulong*)&dw,(WSCulong*)&dh);
+  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
+    if (WSGIbtronAppDev()->haveColorMap() != False){
+      RECT from;
+      from.c.left = 0;
+      from.c.top = 0;
+      from.c.right = pw;
+      from.c.bottom = ph;
+      RECT to;
+      to.c.left = 0;
+      to.c.top = 0;
+      to.c.right = pw;
+      to.c.bottom = ph;
+      gcop_bmp(mem_gid2,&from,mem_gid1,&to,NULL,G_AND);
+    }
+  }
   RECT from;
   from.c.left = dx -x -xoff;
   from.c.top = dy -y -yoff;
@@ -906,7 +917,11 @@ dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
   to.c.bottom = dh +dy + py;
 dbprintf("WSDbtronDraw::drawImage() start copy bmp %d,%d,%d,%d\n",dx+px,dy+py,dw,dh);
   if ((long)mem_gid2 != -1 && mem_gid2 != 0){
-    gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_AND);
+    if (WSGIbtronAppDev()->haveColorMap() == False){
+      gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_AND);
+    }else{
+      gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_ANDN);
+    }
     gcop_bmp(mem_gid1,&from,_gid,&to,NULL,G_OR);
   }else{
     gcop_bmp(mem_gid1,&from,_gid,&to,NULL,G_STORE);
@@ -933,16 +948,12 @@ long WSDbtronDraw::drawStretchedImage(short x,short y,WSCushort w,WSCushort h,WS
   GID mem_gid2 = (GID)image->getValue2();
 
 dbprintf(">> WSDbtronDraw::drawStretchedImage mem_gid=0x%x\n",mem_gid1);
-  if ((long)mem_gid1 == -1 && mem_gid1 != 0){
+  if ((long)mem_gid1 == -1 || mem_gid1 == 0){
     return WS_NO_ERR;
   }
-  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
-dbprintf("WSDbtronDraw::drawStretchedImage need implement about mask pix\n");
-#if 0
-    XSetClipMask(_display,_gc,pix2);
-    XSetClipOrigin(_display,_gc,sx,sy);
-#endif
-  }
+//  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
+//dbprintf("WSDbtronDraw::drawStretchedImage need implement about mask pix\n");
+//  }
 
   WSCulong iw = image->getImageWidth();
   WSCulong ih = image->getImageHeight();
@@ -954,6 +965,21 @@ dbprintf("WSDbtronDraw::drawStretchedImage need implement about mask pix\n");
     px = 0;
     py = 0;
   }
+  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
+    if (WSGIbtronAppDev()->haveColorMap() != False){
+      RECT from;
+      from.c.left = 0;
+      from.c.top = 0;
+      from.c.right = iw;
+      from.c.bottom = ih;
+      RECT to;
+      to.c.left = 0;
+      to.c.top = 0;
+      to.c.right = iw;
+      to.c.bottom = ih;
+      gcop_bmp(mem_gid2,&from,mem_gid1,&to,NULL,G_AND);
+    }
+  }
   RECT from;
   from.c.left = 0;
   from.c.top = 0;
@@ -967,7 +993,11 @@ dbprintf("WSDbtronDraw::drawStretchedImage need implement about mask pix\n");
   to.c.bottom = h +y + py;
 dbprintf("WSDbtronDraw::drawStretchedImage() start copy bmp\n");
   if ((long)mem_gid2 != -1 && mem_gid2 != 0){
-    gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_AND);
+    if (WSGIbtronAppDev()->haveColorMap() == False){
+      gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_AND);
+    }else{
+      gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_ANDN);
+    }
     gcop_bmp(mem_gid1,&from,_gid,&to,NULL,G_OR);
   }else{
     gcop_bmp(mem_gid1,&from,_gid,&to,NULL,G_STORE);
@@ -990,12 +1020,12 @@ dbprintf(">> WSDbtronDraw::drawImage start\n");
   GID mem_gid2 = (GID)image->getValue2();
 dbprintf(">> WSDbtronDraw::drawImage mem_gid=0x%x\n",mem_gid1);
 
-  if ((long)mem_gid1 == -1 && mem_gid1 != 0){
+  if ((long)mem_gid1 == -1 || mem_gid1 == 0){
     return WS_NO_ERR;
   }
-  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
-dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
-  }
+//  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
+//dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
+//  }
   short px,py;
   if (_fdev != NULL){
     _fdev->getAbstPos(&px,&py);
@@ -1007,7 +1037,24 @@ dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
   long dx,dy;
   long dw,dh;
   WSGFandArea(x,y,w,h,_clip_x-px,_clip_y-py,_clip_w,_clip_h,&dx,&dy,(WSCulong*)&dw,(WSCulong*)&dh);
-
+  if ((long)mem_gid2 != -1 && mem_gid2 != 0){
+    if (WSGIbtronAppDev()->haveColorMap() != False){
+      WSCushort pw = image->getImageWidth();
+      WSCushort ph = image->getImageHeight();
+      RECT from;
+      from.c.left = 0;
+      from.c.top = 0;
+      from.c.right = pw;
+      from.c.bottom = ph;
+      RECT to;
+      to.c.left = 0;
+      to.c.top = 0;
+      to.c.right = pw;
+      to.c.bottom = ph;
+      gcop_bmp(mem_gid2,&from,mem_gid1,&to,NULL,G_AND);
+    }
+  }
+ 
   RECT from;
   from.c.left = dx -x +sx;
   from.c.top = dy -y +sy;
@@ -1020,7 +1067,11 @@ dbprintf("WSDbtronDraw::drawImage need implement about mask pix\n");
   to.c.bottom = dh +dy + py;
 dbprintf("WSDbtronDraw::drawImage() start copy bmp\n");
   if ((long)mem_gid2 != -1 && mem_gid2 != 0){
-    gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_AND);
+    if (WSGIbtronAppDev()->haveColorMap() == False){
+      gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_AND);
+    }else{
+      gcop_bmp(mem_gid2,&from,_gid,&to,NULL,G_ANDN);
+    }
     gcop_bmp(mem_gid1,&from,_gid,&to,NULL,G_OR);
   }else{
     gcop_bmp(mem_gid1,&from,_gid,&to,NULL,G_STORE);
