@@ -390,22 +390,49 @@ void WSDbtronFormDev::_copy_area(long x,long y,WSCulong w,WSCulong h,long dx,lon
 #endif
 #endif
   }else{
-    if (_gid == NULL){
+    if (getParentMemGID() == NULL){
       return;
     }
     RECT from;
     from.c.left = x + px;
     from.c.top = y + py;
     from.c.right = w +x + px;
-    from.c.bottom = h +y + px;
+    from.c.bottom = h +y + py;
 
     RECT to;
     to.c.left = dx+px;
-    to.c.top = dy+px;
+    to.c.top = dy+py;
     to.c.right = w +dx + px;
     to.c.bottom = h +dy + py;
-    setDefaultRegion();
-    gcop_bmp(_gid,&from,_gid,&to,NULL,G_STORE);
+
+//    gset_for(getParentMemGID(),NULL);
+//    gset_vis(getParentMemGID(),from);
+    gset_for(getParentGID(),NULL);
+    W ppid;
+    if (_expose_sequence == False || wget_act(&ppid) != getWindowResource()){
+//printf("WSDbtronFormDev::_copy_area vis=%d,%d,%d,%d\n",px+dx,py+dy,w,h);
+      gset_vis(getParentGID(),to);
+    }else{
+      long gx,gy;
+      WSCulong gw,gh;
+      WSGFandArea(_exposed_global_region_x,
+                  _exposed_global_region_y,
+                  _exposed_global_region_w,
+                  _exposed_global_region_h,
+                  dx + px, dy + py,w,h,
+                  &gx,&gy,&gw,&gh);
+      RECT vis;
+      vis.c.left = gx;
+      vis.c.top = gy;
+      vis.c.right = gx + gw;
+      vis.c.bottom = gy + gh;
+      gset_vis(getParentGID(),vis);
+//printf("WSDbtronFormDev::_copy_area vis=%d,%d,%d,%d\n",gx,gy,gw,gh);
+    }
+
+    if (getParentGID() != NULL){
+      gcop_bmp(getParentGID(),&from,getParentGID(),&to,NULL,G_STORE);
+    }
   }
 }
 
@@ -560,7 +587,7 @@ dbprintf("## WSDbtronFormDev::_setup_pixmap _mem_gid=0x%x\n",_mem_gid);
           to.c.top = ch + py;
           to.c.right = pw +cw + px;
           to.c.bottom = ph +ch + py;
-          if (pid2 != 0 || pid2 != -1){
+          if (pid2 != 0 && pid2 != -1){
             gcop_bmp(pid2,&from,getParentMemGID(),&to,NULL,G_AND);
             gcop_bmp(pid,&from,getParentMemGID(),&to,NULL,G_OR);
           }else{
