@@ -48,7 +48,7 @@ extern "C" {
 #include <btron/WSDbtronAppDev.h>
 #include <btron/WSDbtronColor.h>
 
-long WSGFbtronBufToPixmap(unsigned char *buf,W* pixmap,long width,long height,long* vw,long* vh);
+long WSGFbtronBufToPixmap(unsigned char *buf,W* pixmap,long width,long height,long* vw,long* vh,long row_bytes);
 long WSGFbtronBmpReadFpToPixmap(FILE* ifile,W* pixmap,long* w,long* h);
 long WSGFbtronBmpReadFileToPixmap(char* filename,W* pixmap,long* w,long* h);
 long PngReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long* h);
@@ -118,7 +118,7 @@ dbprintf("IMG>> WSDbtronImage::initialize img=%s\n",in.getString());
        setImageWidth(width);
        setImageHeight(height);
        setValue1((long)mem_gid);
-       setValue2((long)mem_gid);
+       setValue2((long)mem_gid2);
      }else{
 //WSMFtrace("ERROR. WSDbtronImage::initialize file open error. file=%s\n",load_file_name);
      }
@@ -191,26 +191,6 @@ long WSDbtronImage::destroy(){
   return WS_NO_ERR;
 }
 long WSDbtronImage::createImage(){
-#if 0
-  Pixmap pix1 = (Pixmap)getValue1();
-  if ((long)pix1 == 0 || (long)pix1 == -1){
-    return WS_ERR;
-  }
-  XImage* image = (XImage*)getValue3();
-  if ((long)image != 0 && (long)image != -1){
-    if ( image->data != NULL){
-      delete image->data;
-      image->data = NULL;
-    }
-    XDestroyImage(image);
-    setValue3(-1);
-  }
-  WSDbtronAppDev* app   = WSGIxwinAppDev();
-  image = XGetImage(app->display(),pix1,0,0,getImageWidth(),
-                    getImageHeight(),0xffffffff,ZPixmap);
-//printf("XGetImage w,h=%d,%d\n",getImageWidth(),getImageHeight());
-  setValue3((long)image);
-#endif
   return WS_NO_ERR;
 }
 
@@ -537,7 +517,7 @@ long WSGFbtronBmpReadFpToPixmap(FILE* ifile,W* pixmap,long* w,long* h){
     }
   }
   delete fbuf;
-  long reti = WSGFbtronBufToPixmap(buf, pixmap, width, height,w,h);
+  long reti = WSGFbtronBufToPixmap(buf, pixmap, width, height,w,h,width*3);
 
   delete buf;
 //  *w = width;
@@ -545,7 +525,7 @@ long WSGFbtronBmpReadFpToPixmap(FILE* ifile,W* pixmap,long* w,long* h){
   return reti;
 }
 
-long WSGFbtronBufToPixmap(unsigned char *buf,W* mem_gid,long rwidth,long rheight,long* w,long* h){
+long WSGFbtronBufToPixmap(unsigned char *buf,W* mem_gid,long rwidth,long rheight,long* w,long* h,long row_bytes){
 
   long stretched = 0;
   long vwidth = *w;
@@ -593,10 +573,11 @@ long WSGFbtronBufToPixmap(unsigned char *buf,W* mem_gid,long rwidth,long rheight
       pt.y = i;
       gdra_pnt(*mem_gid,pt,pixval,G_STORE);
     }
+    ptr = row_bytes*i;
   }
   return 0;
 }
-long WSGFbtronBufToPixmap2(unsigned char *buf,W* mem_gid,W* mem_gid2,long rwidth,long rheight,long* w,long* h){
+long WSGFbtronBufToPixmap2(unsigned char *buf,W* mem_gid,W* mem_gid2,long rwidth,long rheight,long* w,long* h,long row_bytes){
 
   long stretched = 0;
   long vwidth = *w;
@@ -653,6 +634,7 @@ long WSGFbtronBufToPixmap2(unsigned char *buf,W* mem_gid,W* mem_gid2,long rwidth
       gcnv_col(*mem_gid2,val,&pixval);
       gdra_pnt(*mem_gid2,pt,pixval,G_STORE);
     }
+    ptr = row_bytes*i;
   }
   return 0;
 }
@@ -817,12 +799,12 @@ fprintf(stderr,"png read error: out of memory..\n");
     png_read_end(png_ptr,NULL);
     delete png_row_ptrs;
     if (components == 4){
-      WSGFbtronBufToPixmap2(buf, mem_gid,mem_gid2,png_width,png_height,w,h);
+      WSGFbtronBufToPixmap2(buf, mem_gid,mem_gid2,png_width,png_height,w,h,png_row_bytes);
     }else if (components == 3){
       *mem_gid2 = 0;
-      WSGFbtronBufToPixmap(buf, mem_gid,png_width,png_height,w,h);
+      WSGFbtronBufToPixmap(buf, mem_gid,png_width,png_height,w,h,png_row_bytes);
     }else if (components == 2){
-      WSGFbtronBufToPixmap2(buf, mem_gid,mem_gid2,png_width,png_height,w,h);
+      WSGFbtronBufToPixmap2(buf, mem_gid,mem_gid2,png_width,png_height,w,h,png_row_bytes);
     }else{
       delete buf;
       png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
@@ -967,11 +949,11 @@ long JpegReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long
       jpeg_read_scanlines(&jinf, rowptr,1);
     }
     if (components == 4){
-      WSGFbtronBufToPixmap2(buf, mem_gid,mem_gid2,rwidth,rheight,w,h);
+      WSGFbtronBufToPixmap2(buf, mem_gid,mem_gid2,rwidth,rheight,w,h,components*rwidth*sizeof(JSAMPLE));
     }else
     if (components == 3){
       *mem_gid2 = 0;
-      WSGFbtronBufToPixmap(buf, mem_gid,rwidth,rheight,w,h);
+      WSGFbtronBufToPixmap(buf, mem_gid,rwidth,rheight,w,h,components*rwidth*sizeof(JSAMPLE));
     }else{
       delete buf;
       jpeg_finish_decompress(&jinf);
