@@ -153,7 +153,7 @@ long WSCdbMysqlDatabase::sqlExecute(const char* stmt)
 		return WS_ERR;
 	}
 	long ret = WS_NO_ERR;
-	if(mysql_query(_hconn, stmt)) {
+	if(mysql_query(_hconn, decode(stmt))) {
 		getError();
 		ret = WS_ERR;
 	}
@@ -342,6 +342,18 @@ void WSCdbMysqlDatabase::getServerEncoding()
 	}
 	TRACE_U(("getServerEncoding code:%s, _encoding:%d\n", code, _encoding));
 }
+char* WSCdbMysqlDatabase::decode(const char* buf)
+{
+	long decode = WSGIappLocaleSet()->getDefaultEncoding();
+	static WSCstring s;
+	s = buf;
+	if(_encoding != decode && _encoding != -1) {
+	TRACE_U(("decode buf:%s\n", buf));
+	TRACE_U(("decode str:%s\n", s.getString(_encoding)));
+		return s.getString(_encoding);
+	}
+	return s.getString();
+}
 
 /////
 WSCdbMysqlRecord::WSCdbMysqlRecord(WSCdbMysqlDatabase* pDatabase) : WSCdbDrvRecord(pDatabase)
@@ -411,7 +423,8 @@ long WSCdbMysqlRecord::open(const char* stmt, short eCousor, short eAccess)
 	strncpy(buf1, stmt, 6);
 	buf1[6] = '\0';
 
-	if(WSGFstricmp(buf1, "select") == 0) {
+	if(_access != WSCDB_SQL_CONCUR_READ_ONLY 
+		&& WSGFstricmp(buf1, "select") == 0) {
 		getTableName((char*)stmt, _tableName, sizeof(_tableName));
 
 		sprintf(buf1, "select _rowid from %s", _tableName);
@@ -594,9 +607,6 @@ long WSCdbMysqlRecord::moveLast()
 }
 long WSCdbMysqlRecord::setRowPos(WSCulong pos)
 {
-	for(int i = 0; i < _Cols; i++) {
-		memset(_fd[i].buff, '\0', _fd[i].buffLen);
-	}
 	_FetchRowPos = pos;
 	mysql_data_seek(_res_stmt, _FetchRowPos);
 	MYSQL_ROW row = mysql_fetch_row(_res_stmt);
@@ -1070,3 +1080,14 @@ long WSCdbMysqlRecord::getColTypeConv(long index)
 	}
 	return WSCDB_FIELD_TYPE_NONE;
 }
+WSCstring WSCdbMysqlRecord::getErrorMessage()
+{
+  WSCstring ret;
+  char stat[10];
+  char buf[MYSQL_MAX_MESSAGE_LENGTH+1];
+  getErrorMsg(stat,buf);
+  char buf2[MYSQL_MAX_MESSAGE_LENGTH+1+32];
+  sprintf(buf2,"state: %s ,message: %s",stat,buf);
+  ret.setString(buf2);
+  return ret;
+}
