@@ -495,10 +495,6 @@ long WSCodbcRecord::moveNext()
 	_access_mode = CODBC_ACCESS_MODE_READ;
 // update 2002/06/05
 //    sqlrc = SQLFetch(_hstmt);
-// update 2004/01/07
-	for(int i = 0; i < _Cols; i++) {
-		memset(_fd[i].buff, '\0', _fd[i].buffLen);
-	}
 	sqlrc = SQLFetchScroll(_hstmt, SQL_FETCH_NEXT , 0);
 	if(sqlrc == SQL_NO_DATA_FOUND) {
 		_eof = True;
@@ -509,10 +505,6 @@ long WSCodbcRecord::movePrevious()
 {
 	SQLRETURN	sqlrc = SQL_SUCCESS;
 	_access_mode = CODBC_ACCESS_MODE_READ;
-// update 2004/01/07
-	for(int i = 0; i < _Cols; i++) {
-		memset(_fd[i].buff, '\0', _fd[i].buffLen);
-	}
 	sqlrc = SQLFetchScroll(_hstmt, SQL_FETCH_PRIOR, 1);
 	if(sqlrc == SQL_ROW_SUCCESS) {
 		_eof = False;
@@ -523,10 +515,6 @@ long WSCodbcRecord::moveFirst()
 {
 	SQLRETURN	sqlrc = SQL_SUCCESS;
 	_access_mode = CODBC_ACCESS_MODE_READ;
-// update 2004/01/07
-	for(int i = 0; i < _Cols; i++) {
-		memset(_fd[i].buff, '\0', _fd[i].buffLen);
-	}
 	sqlrc = SQLFetchScroll(_hstmt, SQL_FETCH_FIRST, 1);
 	if(sqlrc == SQL_ROW_SUCCESS) {
 		_eof = False;
@@ -540,10 +528,6 @@ long WSCodbcRecord::moveLast()
 		return WS_ERR;
 	}
 	_access_mode = CODBC_ACCESS_MODE_READ;
-// update 2004/01/07
-	for(int i = 0; i < _Cols; i++) {
-		memset(_fd[i].buff, '\0', _fd[i].buffLen);
-	}
 	sqlrc = SQLFetchScroll(_hstmt, SQL_FETCH_LAST, 1);
 	return WS_NO_ERR;
 }
@@ -885,3 +869,13 @@ long WSCodbcRecord::getColTypeConv(long index)
 
 	return WSCDB_FIELD_TYPE_NONE;
 }
+WSCstring WSCodbcRecord::getErrorMessage(){
+  WSCstring ret;
+  char stat[10];
+  char buf[SQL_MAX_MESSAGE_LENGTH+1];
+  getErrorMsg(stat,buf);
+  char buf2[SQL_MAX_MESSAGE_LENGTH+1+32];
+  sprintf(buf2,"state: %s ,message: %s",stat,buf);
+  ret.setString(buf2);
+  return ret;
+}
