@@ -188,7 +188,10 @@ long WSCdbPgsqlDatabase::sqlExecute(const char* stmt)
 	}
 	long ret = WS_NO_ERR;
 	PGresult* res = NULL;
-	res = PQexec(_hconn, stmt);
+
+	TRACE_U(("decode(%s)\n", decode(stmt)));
+
+	res = PQexec(_hconn, decode(stmt));
 	if(IS_PGSQL_ERROR(res)) {
 		getError();
 		ret = WS_ERR;
@@ -334,6 +337,21 @@ void WSCdbPgsqlDatabase::encoding_conv(long code)
 	}
 	TRACE_U(("encoding_conv code:%d, _encoding:%d\n", code, _encoding));
 }
+char* WSCdbPgsqlDatabase::decode(const char* buf)
+{
+	long code = WSGIappLocaleSet()->getDefaultEncoding();
+	static WSCstring s;
+	s = buf;
+
+	TRACE_U(("decode buf:%s _encoding=%d, decode=%d\n", buf, _encoding, code));
+
+	if(_encoding != code && _encoding != -1) {
+	TRACE_U(("decode buf:%s\n", buf));
+	TRACE_U(("decode str:%s\n", s.getString(_encoding)));
+		return s.getString(_encoding);
+	}
+	return s.getString();
+}
 
 /////
 WSCdbPgsqlRecord::WSCdbPgsqlRecord(WSCdbPgsqlDatabase* pDatabase) : WSCdbDrvRecord(pDatabase)
@@ -409,7 +427,8 @@ long WSCdbPgsqlRecord::open(const char* stmt, short eCousor, short eAccess)
 	strncpy(buf1, stmt, 6);
 	buf1[6] = '\0';
 
-	if(WSGFstricmp(buf1, "select") == 0) {
+	if(_access != WSCDB_SQL_CONCUR_READ_ONLY
+		&& WSGFstricmp(buf1, "select") == 0) {
 		select = True;
 		if(!_pDB->getbeginTranmode()) {
 			if(_pDB->beginTran() == WS_ERR) {
@@ -446,6 +465,9 @@ long WSCdbPgsqlRecord::open(const char* stmt, short eCousor, short eAccess)
 				sprintf(oid, "select %s.oid as oid_%s,", _tableName, _CurrsorName);
 				TRACE_U(("WSCdbPgsqlRecord::open oid use"));
 			}
+			PQclear(res);
+			sprintf(buf2, "CLOSE %s", _CurrsorName);
+			res = PQexec(_pDB->_hconn, buf2);
 		}
 		PQclear(res);
 
@@ -1143,3 +1165,14 @@ long WSCdbPgsqlRecord::getColTypeConv(long index)
 	}
 	return WSCDB_FIELD_TYPE_NONE;
 }
+WSCstring WSCdbPgsqlRecord::getErrorMessage()
+{
+  WSCstring ret;
+  char stat[10];
+  char buf[PGSQL_MAX_MESSAGE_LENGTH+1];
+  getErrorMsg(stat,buf);
+  char buf2[PGSQL_MAX_MESSAGE_LENGTH+1+32];
+  sprintf(buf2,"state: %s ,message: %s",stat,buf);
+  ret.setString(buf2);
+  return ret;
+}
