@@ -7,8 +7,8 @@
 extern VALUE mMpfc;
 
 void _procedure_handler(char* fname,WSCbase* ptr){
-  VALUE  klass = rb_const_get(mMpfc, rb_intern("WSCbase"));
-  VALUE  obj = Data_Wrap_Struct(klass, 0, 0, ptr);
+  VALUE  klass = rb_const_get(mMpfc, rb_intern(ptr->getClassName()));
+  VALUE  obj = Data_Wrap_Struct(klass, 0, 0, ptr->cast(ptr->getClassName()));
   rb_funcall(NULL,rb_intern(fname),1,obj);
 //printf("_procedure_handler...\n");
 }
