@@ -7,8 +7,8 @@ char* _WSNcols              = "cols";
 char* _WSNfixedRows         = "fixedRows"; 
 char* _WSNfixedCols         = "fixedCols"; 
 char* _WSNgridLines         = "gridLines"; 
-char* _WSNcelldefWidth      = "cellDefWidth"; 
-char* _WSNcelldefHeight     = "cellDefHeight"; 
+char* _WSNcellDefWidth      = "cellDefWidth"; 
+char* _WSNcellDefHeight     = "cellDefHeight"; 
 char* _WSNfixedColHeight    = "fixedColHeight"; 
 char* _WSNcellDefFont       = "cellDefFont"; 
 char* _WSNfixedCellFont     = "fixedCellFont"; 
@@ -40,8 +40,8 @@ char* _WSNcols              () { return "cols"; };
 char* _WSNfixedRows         () { return "fixedRows"; };
 char* _WSNfixedCols         () { return "fixedCols"; };
 char* _WSNgridLines         () { return "gridLines"; };
-char* _WSNcelldefWidth      () { return "cellDefWidth"; };
-char* _WSNcelldefHeight     () { return "cellDefHeight"; };
+char* _WSNcellDefWidth      () { return "cellDefWidth"; };
+char* _WSNcellDefHeight     () { return "cellDefHeight"; };
 char* _WSNfixedColHeight    () { return "fixedColHeight"; };
 char* _WSNcellDefFont       () { return "cellDefFont"; };
 char* _WSNfixedCellFont     () { return "fixedCellFont"; };
