@@ -39,6 +39,9 @@
 #include <win/WSDwinMessage.h>
 #include <win/WSDwinsocket.h>
 #include <WSCinitializeManager.h>
+#include <win/WSDwinThread.h>
+#include <win/WSDwinMutex.h>
+#include <win/WSDwinSemaphore.h>
 
 #define COLOR_MAX 256
 WSMFclassInit(WSDwinAppDev,WSDappDev);
@@ -113,6 +116,12 @@ extern WSDcodeConvert* _code_convert_create_handler_();
     WSGIappImageSet()->setDefaultImageHandle("$(WSDIR)/sys/pixmaps/bi41.ico",(void*)233);
     WSGIappImageSet()->setDefaultImageHandle("$(WSDIR)/sys/pixmaps/bi42.ico",(void*)234);
     WSGIappImageSet()->setDefaultImageHandle("$(WSDIR)/sys/pixmaps/bi43.ico",(void*)235);
+extern void WSGFinitializeWinMutex();
+    WSGFinitializeWinMutex();
+extern void WSGFinitializeWinThread();
+    WSGFinitializeWinThread();
+extern void WSGFinitializeWinSemaphore();
+    WSGFinitializeWinSemaphore();
 extern void _win_font_init();
     _win_font_init();
 extern void _win_color_init();
@@ -392,6 +401,15 @@ dbprintf("WndProc %s:%d done2\n",__FILE__,__LINE__);
 dbprintf("WndProc %s:%d done3\n",__FILE__,__LINE__);
     return 0;
   }
+  if (message == WM_USER && uParam == WS_WIN_THR){
+    WSDwinThread* ptr = (WSDwinThread*)lParam;
+    void (*fn)(WSDthread*,void*) =
+           (void(*)(WSDthread*,void*))ptr->getCallbackFunction();
+    fn(ptr,ptr->getCallbackData());
+    WSGIappObjectList()->execInitialize();
+    WSGIappObjectList()->execUpdate();
+    return 0;
+  }
   if (message == WM_USER){
     int ret = WSDwinMessage::receiveMessage((WSDwinMessage*)uParam,(void*)lParam);
     if (ret != False){
@@ -567,6 +585,15 @@ void WSDwinAppDev::update(){
     d->setExposed(True);
     d->_clear_and_expose();
   }
+  while(1){
+    long ret = PeekMessage(&_msg,NULL,0,0,PM_REMOVE);
+    if (ret != FALSE){
+      TranslateMessage(&_msg);
+      DispatchMessage(&_msg);
+    }else{
+      break;
+    }
+  }
 }
 struct WSDpalette{
   LOGPALETTE   plt;
