@@ -591,6 +591,9 @@ WSMFtrace("WSDwinformDev::createWindow() remove delete callback is not implement
     }
   }
 #endif
+  if (getVisible() == False){
+    return WS_NO_ERR;
+  }
   short x,y;    
   WSCushort w,h;    
   getWindowSize(&x,&y,&w,&h);
@@ -924,6 +927,13 @@ long WSDwinformDev::setVisible(WSCbool fl){
   WSCbool bk = getVisible();
   WSDdev::setVisible(fl);
 //WSMFtrace("WSDwinformDev::setVisible %d this=0x%x client->%s  parent=0x%x  parent=%s========================\n",fl,this,getAttachedClient()->getInstanceName(),getParentDev(),getParentDev()->getAttachedClient()->getInstanceName());
+  if (fl == True){
+    if (getAttachedClient() == NULL){
+      fl = False;
+    }else if (getAttachedClient()->getVisible() == False){
+      fl = False;
+    }
+  }
   if (fl == False){
     WSDwinformDev* mdev = WSGIwinAppDev()->getMouseFocusDev();
     if (mdev == this){
