@@ -260,7 +260,7 @@ void* WSDwinsocket::_udp_read_thread_(void* ptr){
         (unsigned long)inet_addr((char*)_this->_naddr);
     }
     server.sin_port = htons( _this->_port );
-printf("WSDxsocket::_udp_read_thread bind\n");
+//printf("WSDxsocket::_udp_read_thread bind\n");
     if( bind(_this->_socket, (struct sockaddr *)&server, sizeof(server)) < 0){
       _this->seterr();
       return NULL;
@@ -278,26 +278,26 @@ printf("WSDxsocket::_udp_read_thread bind\n");
     fd_set read_fds;
     FD_ZERO(&read_fds);
     FD_SET((SOCKET)_this->_socket,&read_fds);
-printf("WSDxsocket::_udp_read_thread before select\n");
+//printf("WSDxsocket::_udp_read_thread before select\n");
     long ret = select(FD_SETSIZE,&read_fds,NULL,NULL,&tm);
     long err = WSAGetLastError();
-printf("WSDxsocket::_udp_read_thread after select\n");
+//printf("WSDxsocket::_udp_read_thread after select\n");
     if (ret < 0 && err != WSAEALREADY){
-printf("WSDxsocket::_udp_read_thread after return1\n");
+//printf("WSDxsocket::_udp_read_thread after return1\n");
       _this->seterr();
       return NULL;
     }
     if (ret < 0){
-printf("WSDxsocket::_udp_read_thread after timeout continue\n");
+//printf("WSDxsocket::_udp_read_thread after timeout continue\n");
       continue;
     }
     if (ret == 0){
-printf("WSDxsocket::_udp_read_thread after timeout continue2\n");
+//printf("WSDxsocket::_udp_read_thread after timeout continue2\n");
       continue;
     }
 
     if (_this->_stop_accept != False){
-printf("WSDxsocket::_udp_read_thread after return2\n");
+//printf("WSDxsocket::_udp_read_thread after return2\n");
       _this->seterr();
       _this->_stop_accept = False;
       return 0;
@@ -310,7 +310,7 @@ printf("WSDxsocket::_udp_read_thread after return2\n");
     data->socket = _this->_socket;
     data->addr = 0;
     data->hd = hd;
-printf("WSDxsocket::_udp_read_thread create sem, send msg\n");
+//printf("WSDxsocket::_udp_read_thread create sem, send msg\n");
 
     DWORD result;
 //    ret = SendMessageTimeout( WSGIwinAppDev()->getHWND(),
@@ -327,7 +327,7 @@ printf("WSDxsocket::_udp_read_thread create sem, send msg\n");
     }    
 #endif
     WaitForSingleObject(sem,INFINITE);
-printf("WSDxsocket::_udp_read_thread after sem.\n");
+//printf("WSDxsocket::_udp_read_thread after sem.\n");
     _this->_sem = (HANDLE)NULL;
     CloseHandle(sem);
     if (_this->_stop_accept != False){
@@ -603,7 +603,7 @@ long WSDwinsocket::write(void* handle,WSCuchar* buf,long size){
                    (sockaddr*)&toaddr,sizeof(toaddr));
     }
     long err = WSAGetLastError();
-printf("WSDxsocket::write send ret=%d err=%d\n",ret,err);
+//printf("WSDxsocket::write send ret=%d err=%d\n",ret,err);
 
     if (timeout > 0){
       if (ret > 0){
