@@ -532,7 +532,8 @@ dbprintf("WSDwinwinDev::createWindow %s:%d alt=0x%x\n",__FILE__,__LINE__,alt_hwn
       _shell = CreateWindowEx( _style_ex,szAppName,"",
              _style | WS_CLIPSIBLINGS | WS_POPUP | WS_CLIPCHILDREN, x,y,w,h,pw,
                         NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
-      SetWindowPos(_shell,HWND_TOPMOST,0,0,0,0,SWP_NOMOVE|SWP_NOSIZE);
+      SetWindowPos(_shell,HWND_TOPMOST,0,0,0,0,SWP_NOMOVE|SWP_NOSIZE|SWP_NOACTIVATE);
+//      SetWindowPos(_shell,HWND_TOPMOST,0,0,0,0,SWP_NOMOVE|SWP_NOSIZE);
 //WSMFtrace("CreateWindow NO_FRAME XXZZq2  %d,%d,%d,%d\n",x,y,w,h);
     }else{
       _shell = CreateWindowEx( _style_ex,szAppName,"", _style | WS_CLIPSIBLINGS | WS_CLIPCHILDREN, x,y,w,h,NULL,
