@@ -83,12 +83,18 @@ int _win_main2(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int n
   WSDdev::setDraw(new WSDwindraw());
 
 WSMFtrace("main start:\n");
+dbprintf("_win_main2 %s:%d start\n",__FILE__,__LINE__);
   if (!hPrevInstance){
     if (!InitApplication(hInstance)){
-      return (FALSE);
+      if (WSGIappDev()->getMode() == WS_MODE_NORMAL){
+dbprintf("_win_main2 %s:%d done1\n",__FILE__,__LINE__);
+//TEST
+//        return (FALSE);
+      }
     }
   }
   if (!InitInstance(hInstance,nCmdShow)){
+dbprintf("_win_main2 %s:%d done2\n",__FILE__,__LINE__);
     return FALSE;
   }
 
@@ -103,7 +109,7 @@ WSMFtrace("main start:\n");
 WSMFtrace("main 1:\n");
 
 
-printf("cmd=#%s#",GetCommandLine());
+//printf("cmd=#%s#",GetCommandLine());
    char* cmd = WSGFstrdup(GetCommandLine());
    long len = strlen(cmd)+1;
    long i;
@@ -139,20 +145,23 @@ printf("cmd=#%s#",GetCommandLine());
    char** cprm = new char*[lines+1];
    for(i=0; i<lines; i++){
      cprm[i] = (char*)plist[i];
-printf("#%s#\n",cprm[i]);
+//printf("#%s#\n",cprm[i]);
    } 
    cprm[lines] = NULL;
    winApp->setInitPrm(lines,cprm);
    delete cmd;
  
-   winApp->execInitHandler();
 WSMFtrace("main 2:\n");
 
+dbprintf("_win_main2 %s:%d done\n",__FILE__,__LINE__);
    return 0;
 }
 
 int WSGFwsInitialize(){
+static long cnt = 0;
   HINSTANCE hInst = GetModuleHandle(NULL);
+dbprintf("WSGFwsInitialize() %s:%d start hInst=0x%x cnt=%d\n",__FILE__,__LINE__,hInst,cnt);
+cnt++;
   LPSTR cmd = GetCommandLine();
   _win_main2(hInst,NULL,cmd,TRUE);
   
@@ -161,10 +170,12 @@ int WSGFwsInitialize(){
 
 extern "C" {
 int _win_main(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int nCmdShow){
+  _dbprintf_init();
   _win_main2(hInstance,hPrevInstance,lpCmdLine,nCmdShow);
 
 
   WSDwinAppDev* winApp = WSGIwinAppDev();
+  winApp->execInitHandler();
   winApp->handleEvents();
   return 0;
 }
