@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -200,7 +200,8 @@ static void searchop(WSCbase*){
             }
             if (found == True){
               obj->setPropertyEditExecute(True);
-              inspector->setPropertyV(WSNvalue,(WSCuchar)2);
+              inspector->setSelectIndexTab(2);
+//              inspector->setPropertyV(WSNvalue,(WSCuchar)2);
               found = True;
               break;
             }
@@ -212,7 +213,8 @@ static void searchop(WSCbase*){
 //printf("%s:%d pname=%s v=%s v=%s\n",__FILE__,__LINE__,(char*)pname2,(char*)val,(char*)valuestr);
               if(!strcmp((char*)val,(char*)valuestr)){
                 obj->setPropertyEditExecute(True);
-                inspector->setPropertyV(WSNvalue,(WSCuchar)2);
+                inspector->setSelectIndexTab(2);
+//                inspector->setPropertyV(WSNvalue,(WSCuchar)2);
                 found = True;
                 break;
               }
@@ -234,7 +236,8 @@ static void searchop(WSCbase*){
               WSCvariant val = obj->getProperty((char*)proparray[i]);
               if(!strcmp((char*)val,(char*)valuestr)){
                 obj->setPropertyEditExecute(True);
-                inspector->setPropertyV(WSNvalue,(WSCuchar)2);
+                inspector->setSelectIndexTab(2);
+//                inspector->setPropertyV(WSNvalue,(WSCuchar)2);
                 found = True;
                 break;
               }
@@ -251,7 +254,8 @@ static void searchop(WSCbase*){
               WSCvariant val = obj->getProperty((char*)pname2);
               if(!strcmp((char*)val,(char*)valuestr)){
                 obj->setPropertyEditExecute(True);
-                inspector->setPropertyV(WSNvalue,(WSCuchar)2);
+                inspector->setSelectIndexTab(2);
+//                inspector->setPropertyV(WSNvalue,(WSCuchar)2);
                 found = True;
                 break;
               }
@@ -295,7 +299,8 @@ static void searchop(WSCbase*){
           }
           if (found == True){
             obj->setPropertyEditExecute(True);
-            inspector->setPropertyV(WSNvalue,(WSCuchar)3);
+            inspector->setSelectIndexTab(3);
+//            inspector->setPropertyV(WSNvalue,(WSCuchar)3);
             break;
           }
         }
@@ -327,7 +332,8 @@ static void searchop(WSCbase*){
           }
           if (found == True){
             obj->setPropertyEditExecute(True);
-            inspector->setPropertyV(WSNvalue,(WSCuchar)3);
+            inspector->setSelectIndexTab(3);
+//            inspector->setPropertyV(WSNvalue,(WSCuchar)3);
             break;
           }
         }
