@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -39,7 +39,7 @@
 #include <advance/WSadcom.h>
 #include <advance/WSCprojectEditor.h>
 #include <advance/WSCinspector.h>
-#include <advance/WSCprocessBox.h>
+#include <advance/WSCprocessForm.h>
 #include <WSCfileSelect.h>
 #include <WSCclassInformation.h>
 #include <WSDtimer.h>
@@ -57,7 +57,7 @@ extern WSCstring         current_dir;
 extern WSCpopupMenu*     popupmenu;
 extern WSCpopupMenu*     popupmenu2;
 extern WSCprojectEditor* pe;
-extern WSCprocessBox*    procbox;
+extern WSCprocessForm*    procform;
 
 
 extern void _register_drop_site(WSCbase* obj);
@@ -65,7 +65,7 @@ extern void _unregister_drop_site(WSCbase* obj);
 extern void _register_popup_menu(WSCbase*);
 extern void _unregister_popup_menu(WSCbase*);
 
-static long title_cnt = 1;
+long title_cnt = 1;
 
 char* get_win_file_name(WSCbase* client){
   WSCstring fname;
@@ -488,41 +488,41 @@ extern char* get_project_dir();
 #ifdef MSW
   if (target->getUserData(WS_WIN_CLASS)){
     str = get_project_dir();
-    procbox->setPropertyV(WSNdirName,(char*)str);
+    procform->setPropertyV(WSNdirName,(char*)str);
     fname = target->getInstanceName();
     str = "";
     str << "rm.exe -f " << fname << ".o " << fname << "P.o";
-    procbox->setPropertyV(WSNfileName,(char*)str);
-    procbox->setVisible(True);
-    procbox->start();
+    procform->setPropertyV(WSNfileName,(char*)str);
+    procform->setVisible(True);
+    procform->start();
     while(1){
-      if (procbox->getHandle() == 0){
+      if (procform->getHandle() == 0){
         break;
       }
       WSGIappDev()->dispatchEvent();
     }
-    procbox->setProperty(WSNlabelString,"");
+    procform->setProperty(WSNlabelString,"");
     str = "";
 extern char* get_make_name();
 //    str << "make " << fname << ".o " << fname << "P.o";
     str << get_make_name() << " " << fname << ".o " << fname << "P.o";
   }else{
     str = get_project_dir();
-    procbox->setPropertyV(WSNdirName,(char*)str);
+    procform->setPropertyV(WSNdirName,(char*)str);
 
     str = "";
     fname = target->getInstanceName();
     str << "rm.exe -f " << fname << ".o ;";
-    procbox->setPropertyV(WSNfileName,(char*)str);
-    procbox->setVisible(True);
-    procbox->start();
+    procform->setPropertyV(WSNfileName,(char*)str);
+    procform->setVisible(True);
+    procform->start();
     while(1){
-      if (procbox->getHandle() == 0){
+      if (procform->getHandle() == 0){
         break;
       }
       WSGIappDev()->dispatchEvent();
     }
-    procbox->setProperty(WSNlabelString,"");
+    procform->setProperty(WSNlabelString,"");
 extern char* get_make_name();
     str = "";
 //    str << "make " << fname << ".o ";
@@ -549,12 +549,12 @@ extern char* get_make_name();
 #endif /* MSW */
 //#endif /* FreeBSD */
 
-extern WSCprocessBox* procbox;
+extern WSCprocessForm* procform;
 //printf("execute_buildall exec:%s\n",(char*)str);
-  procbox->setPropertyV(WSNlabelString,"");
-  procbox->setPropertyV(WSNfileName,(char*)str);
-  procbox->setVisible(True);
-  procbox->start();
+  procform->setPropertyV(WSNlabelString,"");
+  procform->setPropertyV(WSNfileName,(char*)str);
+  procform->setVisible(True);
+  procform->start();
 
 }
 void icmpl_work2(WSCbase* menu){
@@ -583,7 +583,8 @@ void iprop_work2(WSCbase* menu){
 //printf("obj=%s\n",target->getInstanceName());
 //extern void under_construction();
 //  under_construction();
-  inspector->setPropertyV(WSNvalue,(WSCuchar)2);
+  inspector->setSelectIndexTab(2);
+//  inspector->setPropertyV(WSNvalue,(WSCuchar)2);
 }
 
 void iop_work2(WSCbase* menu){
@@ -595,7 +596,8 @@ void iop_work2(WSCbase* menu){
 //printf("obj=%s\n",target->getInstanceName());
 //extern void under_construction();
 //  under_construction();
-  inspector->setPropertyV(WSNvalue,(WSCuchar)3);
+  inspector->setSelectIndexTab(3);
+//  inspector->setPropertyV(WSNvalue,(WSCuchar)3);
 }
 void iextprop_work2(WSCbase* menu){
   WSCbase* target;
@@ -606,7 +608,8 @@ void iextprop_work2(WSCbase* menu){
 //printf("obj=%s\n",target->getInstanceName());
 //extern void under_construction();
 //  under_construction();
-  inspector->setPropertyV(WSNvalue,(WSCuchar)4);
+  inspector->setSelectIndexTab(4);
+//  inspector->setPropertyV(WSNvalue,(WSCuchar)4);
 }
 
 
