@@ -50,6 +50,9 @@
 #include <x11/WSDxprivateTimer.h>
 #include <x11/WSDxtimer.h>
 #include <x11/WSDxsocket.h>
+#include <x11/WSDunixThread.h>
+#include <x11/WSDunixMutex.h>
+#include <x11/WSDunixSemaphore.h>
 
 #if 1 //UNICODE
 #include <xunicode.h>
@@ -85,6 +88,12 @@ _xappDev_init _xappDev_init_run_constructor;
 void WSGFdeviceInitialize(){
   static WSCbool initialized = False;
   if (initialized == False){
+extern WSDfile* _unix_sem_chandler();
+    WSDmutex::setCreateInstanceHandler((void*)_unix_sem_chandler);
+extern WSDfile* _unix_mutex_chandler();
+    WSDmutex::setCreateInstanceHandler((void*)_unix_mutex_chandler);
+extern WSDfile* _unix_th_chandler();
+    WSDthread::setCreateInstanceHandler((void*)_unix_th_chandler);
 extern WSDfile* _unix_fp_chandler();
     WSDfile::setCreateInstanceHandler((void*)_unix_fp_chandler);
 extern WSDdragDrop* _xdrag_drop_create_handler_();
@@ -133,6 +142,7 @@ WSDxappDev::WSDxappDev(){
   _gc2 = 0;
   _accept_atom_for_sock = 0;
   _read_event_for_execute = 0;
+  _callback_event_for_thread = 0;
 }
 WSDxappDev::~WSDxappDev(){}
 
@@ -485,6 +495,9 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d ev=%d\n",__FILE__,__LINE__,e.type);
     if (_read_event_for_execute == 0){
       _read_event_for_execute = XInternAtom(_disp,"EXEC-READ",False);
     }
+    if (_callback_event_for_thread == 0){
+      _callback_event_for_thread = XInternAtom(_disp,"THREAD-MESSAGE",False);
+    }
     if (e.xclient.message_type == _accept_atom_for_sock){
 //printf("client message !! here! execute xappdev \n");
       _accept_send_type data;
@@ -509,6 +522,26 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done2\n",__FILE__,__LINE__);
 dbprintf("WSDxappDev::_dispatchEvent %s:%d done3\n",__FILE__,__LINE__);
       return WS_NO_ERR;
     }
+    if (e.xclient.message_type == _callback_event_for_thread){
+//printf("client message !! here! execute xappdev for exec_read\n");
+      WSDunixThread* ptr;
+      memcpy(&ptr,e.xclient.data.l,sizeof(WSDunixThread*));
+
+      if (ptr->getCallbackFunction() != NULL){
+//printf("client message !! here! execute exec_read\n");
+        void(*fn)(WSDunixThread*,void*) =
+             (void(*)(WSDunixThread*,void*))ptr->getCallbackFunction();
+        if (fn != NULL){
+          fn(ptr,ptr->getCallbackData());
+        }
+        WSGIappObjectList()->execInitialize();
+        WSGIappObjectList()->execUpdate();
+      }
+dbprintf("WSDxappDev::_dispatchEvent %s:%d done3\n",__FILE__,__LINE__);
+      return WS_NO_ERR;
+    }
+
+
   }
 
   if (e.type == SelectionClear){
